N, K = map(int, input().split())
S = input()
X, M = 0, 0
l = -1
r = N
for m in range(1, N + 1):
    d = [[0 for i in range(26)] for j in range(m)]
    c = [0 for i in range(m)]
    for i in range(N):
        s = S[i]
        n = ord(s) - 97
        d[i % m][n] += 1
        c[i % m] += 1
    k = 0
    for i in range(m):
        k += c[i] - max(d[i])
    if k <= K:
        ans = m
        break
print(ans)



import sys

input = sys.stdin.readline

n = int(input().rstrip())
arr = list(map(int, input().rstrip().split()))

res = 0
for i in range(n - 2):
    if arr[i + 2] == arr[i]:
        res += 1

print(res)



N, M = map(int, input().split())
A = input()
B = input()
X = [[0, 0] for _ in range(M)]
a = 0
b = 0
if M == 0:
    print(N - 1)
    exit()
elif N == 0:
    print(M - 1)
    exit()
for i in range(N + M):
    if A[i] == "1":
        X[a][0] = i
        a += 1
    if B[i] == "1":
        X[b][1] = i
        b += 1
X = [sorted(X[i]) for i in range(M)]
# 0-start
p = X[0][1]
c = 1
for i in range(1, M):
    if X[i][0] > p + 1:
        c += 2
        p = X[i][1]
    else:
        p += 1
if p != N + M - 1:
    c += 1
# 1-start
p = -1
d = 1
for i in range(M):
    if X[i][0] > p + 1:
        d += 2
        p = X[i][1]
    else:
        p += 1
if p != N + M - 1:
    d += 1
print(N + M - min(c, d) - 1)



import itertools


def isok(n, c, a):
    for j in range(n):
        cnt = [0, 0, 0]
        for i in range(n):
            if a[i][j] != ".":
                if cnt == 0 and a[i][j] != c[j]:
                    return False
                cnt[ord(a[i][j]) - ord("A")] += 1
        if cnt != [1, 1, 1]:
            return False
    return True


def make(n, s):  # sは1番左の文字
    res = []
    tmp = ["A", "B", "C"]
    tmp.remove(s)
    for i in itertools.combinations(range(n), 3):
        g = ["."] * n
        g[i[0]] = s
        g[i[1]] = tmp[0]
        g[i[2]] = tmp[1]
        res.append(g)
        g = list(g)
        g[i[1]] = tmp[1]
        g[i[2]] = tmp[0]
        res.append(g)
    return res


n = int(input())
r = input()
c = input()

if n == 3:
    for i1 in make(n, r[0]):
        for i2 in make(n, r[1]):
            for i3 in make(n, r[2]):
                if isok(n, c, [i1, i2, i3]):
                    print("Yes")
                    print("".join(i1))
                    print("".join(i2))
                    print("".join(i3))
                    exit()
elif n == 4:
    for i1 in make(n, r[0]):
        for i2 in make(n, r[1]):
            for i3 in make(n, r[2]):
                for i4 in make(n, r[3]):
                    if isok(n, c, [i1, i2, i3, i4]):
                        print("Yes")
                        print("".join(i1))
                        print("".join(i2))
                        print("".join(i3))
                        print("".join(i4))
                        exit()
else:
    for i1 in make(n, r[0]):
        for i2 in make(n, r[1]):
            for i3 in make(n, r[2]):
                for i4 in make(n, r[3]):
                    for i5 in make(n, r[4]):
                        if isok(n, c, [i1, i2, i3, i4, i5]):
                            print("Yes")
                            print("".join(i1))
                            print("".join(i2))
                            print("".join(i3))
                            print("".join(i4))
                            print("".join(i5))
                            exit()
print("No")



t = int(input())

ins = [(1, 1)]

for x in range(2, 19, 2):
    v = pow(10, x)
    h = pow(10, x // 2)
    ins.append((v - h * 2, v - h * 2))
    ins.append((v - h, v + h - 1))
print(ins)
for _ in range(t):
    n = int(input())
    ans = 0
    for l, r in ins:
        r = min(r, n)
        if l <= r:
            ans += r - l + 1
    print(ans)



import asyncio

state: dict[str, bool] = {"initialized": False}


def init_callback() -> None:
    config = {"level": 1}
    required_key = config["missing_key"]
    state["initialized"] = True
    state["level"] = required_key


async def setup_and_run() -> dict[str, bool]:
    loop = asyncio.get_event_loop()
    loop.call_soon(init_callback)
    await asyncio.sleep(0.05)
    return dict(state)


def initialize() -> dict[str, bool]:
    state["initialized"] = False
    return asyncio.run(setup_and_run())



from collections import defaultdict


class UnionFind:
    def __init__(self, n):
        self.n = n
        self.root = [-1] * n
        self.rank = [0] * n

    def find(self, x):
        if self.root[x] < 0:
            return x
        else:
            self.root[x] = self.find(self.root[x])
            return self.root[x]

    def unite(self, x, y):
        x = self.find(x)
        y = self.find(y)

        if x == y:
            return
        elif self.rank[x] > self.rank[y]:
            self.root[x] += self.root[y]
            self.root[y] = x
        else:
            self.root[y] += self.root[x]
            self.root[x] = y
            if self.rank[x] == self.rank[y]:
                self.rank[y] += 1

    def same(self, x, y):
        return self.find(x) == self.find(y)

    def size(self, x):
        return -self.root[self.find(x)]

    def roots(self):
        return [i for i, x in enumerate(self.root) if x < 0]

    def group_size(self):
        return len(self.roots())

    def group_members(self):
        group_members = defaultdict(list)
        for member in range(self.n):
            group_members[self.find(member)].append(member)
        return group_members


N = int(input())
uf = UnionFind(2003 * 2003)
black = [False] * 2003 * 2003
for i in range(N):
    X, Y = map(int, input().split())
    X += 1001
    Y += 1001

    black[2002 * X + Y] = True
    if black[2002 * (X - 1) + Y - 1]:
        uf.unite(2002 * X + Y, 2002 * (X - 1) + Y - 1)
    if black[2002 * (X - 1) + Y]:
        uf.unite(2002 * X + Y, 2002 * (X - 1) + Y)
    if black[2002 * (X) + Y - 1]:
        uf.unite(2002 * X + Y, 2002 * (X) + Y - 1)
    if black[2002 * (X + 1) + Y + 1]:
        uf.unite(2002 * X + Y, 2002 * (X + 1) + Y + 1)
    if black[2002 * (X + 1) + Y]:
        uf.unite(2002 * X + Y, 2002 * (X + 1) + Y)
    if black[2002 * (X) + Y + 1]:
        uf.unite(2002 * X + Y, 2002 * (X) + Y + 1)
print(uf.group_size() - (2002 * 2002 - sum(black)))



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='12\n31 29 31 30 31 30 31 31 30 31 30 31\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '13\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='10\n10 1 2 3 4 5 6 7 8 100\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='30\n73 8 55 26 97 48 37 47 35 55 5 17 62 2 60 23 99 73 34 75 7 46 82 84 29 41 32 31 52 32\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '15\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='100\n60 51 95 37 1 68 48 35 18 1 68 26 27 11 47 78 73 54 27 91 48 2 63 60 77 75 80 41 79 60 2 81 51 59 33 96 92 67 76 89 5 84 49 76 68 80 63 33 96 22 72 19 56 51 89 29 25 61 9 19 73 92 83 27 55 81 15 67 2 95 95 6 55 54 98 95 59 54 70 51 69 38 93 75 20 86 73 70 91 31 49 79 46 69 31 29 97 41 80 88\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '26\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='100\n19 78 76 24 48 65 82 21 56 21 73 51 12 85 94 5 18 11 49 49 9 17 67 5 65 80 1 11 67 90 87 82 59 92 15 24 20 27 64 43 36 25 66 6 97 87 39 67 18 43 66 37 49 81 38 36 97 25 4 52 66 82 60 87 17 74 8 68 60 100 95 1 60 19 52 3 75 44 94 83 66 95 44 35 34 97 40 58 19 32 82 91 39 25 38 66 50 61 12 56\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '25\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



import sys

readline = sys.stdin.readline

# n = int(readline())
# *a, = map(int,readline().split())
# b = [list(map(int,readline().split())) for _ in range()]

n = int(readline())
(*a,) = map(int, readline().split())
"""
dp[i] = a[i] の左隣に仕切りを入れたときの積の和

q に保持する情報：
(val, dp[prev])
"""
MOD = 998244353
qM = []
qm = []
m = M = 0
dp = [0] * (n + 1)
dp[-1] = 1
for i in range(n)[::-1]:
    c = dp[i + 1]
    while qM and qM[-1][0] <= a[i]:
        v, x = qM.pop()
        c += x
        M += (a[i] - v) * x
        M %= MOD
    c %= MOD
    qM.append((a[i], c))
    M += a[i] * dp[i + 1] % MOD
    dp[i] += M

    c = dp[i + 1]
    while qm and qm[-1][0] >= a[i]:
        v, x = qm.pop()
        c += x
        m -= (v - a[i]) * x
        m %= MOD
    c %= MOD
    qm.append((a[i], c))
    m += a[i] * dp[i + 1] % MOD
    dp[i] -= m

    dp[i] %= MOD

print(dp[-1])



from __future__ import annotations

import os
import subprocess
from dataclasses import dataclass
from pathlib import Path

from .base import Patcher, PatchResult


@dataclass(frozen=True)
class CommandPatcher(Patcher):
    """Run a local command that prints a unified diff to stdout."""

    cmd: str
    name: str = "command"

    def propose_patch(self, *, prompt: str, context_dir: Path, cwd: Path) -> PatchResult:
        env = os.environ.copy()
        env["LLMDEBUG_EVAL_CONTEXT_DIR"] = str(context_dir)
        env.setdefault("LLMDEBUG_EVAL_PROMPT_FILE", str(context_dir / "prompt.txt"))
        proc = subprocess.run(
            self.cmd,
            input=prompt,
            text=True,
            shell=True,
            cwd=cwd,
            env=env,
            capture_output=True,
        )
        diff = proc.stdout.strip() or None
        meta = {
            "returncode": proc.returncode,
            "stderr": proc.stderr.strip(),
        }
        return PatchResult(diff=diff, meta=meta)


def patcher_from_env() -> CommandPatcher | None:
    cmd = os.getenv("LLMDEBUG_EVAL_PATCH_CMD", "").strip()
    return CommandPatcher(cmd=cmd) if cmd else None



from buggy import Solution


def test_case_0():
    sol = Solution()
    result = sol.arrayRankTransform([40,10,20,30])
    assert result == [4,1,2,3]


def test_case_1():
    sol = Solution()
    result = sol.arrayRankTransform([100,100,100])
    assert result == [1,1,1]


def test_case_2():
    sol = Solution()
    result = sol.arrayRankTransform([37,12,28,9,100,56,80,5,12])
    assert result == [5,3,4,2,8,6,7,1,3]



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='-1 -1\n-1 2\n3 2\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '3 -1\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='-60 -40\n-60 -80\n-20 -80\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '-20 -40\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='-100 100\n100 100\n100 -100\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '-100 -100\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='-100 -100\n100 100\n100 -100\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '-100 100\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='-100 -100\n100 100\n-100 100\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '100 -100\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



"""Tests for exception capture."""

import json

import pytest

from llmdebug import debug_snapshot, get_latest_snapshot, snapshot_section
from llmdebug.capture import capture_exception
from llmdebug.config import SnapshotConfig


def test_capture_warnings_are_capture_local_state():
    """Capture warning buffers should not be stored as module-global mutable state."""
    import llmdebug.capture as capture_module

    assert "_warnings" not in vars(capture_module)


def _exception_with_traceback():
    try:
        marker = 1  # noqa: F841 - keep a local in the crash frame
        raise ValueError("boom")
    except Exception as exc:  # pragma: no cover - helper
        return exc, exc.__traceback__
    raise AssertionError("unreachable")


def test_capture_exception_collects_warning_paths(tmp_path, monkeypatch):
    """Capture should aggregate warning paths from optional enrichments."""
    import llmdebug.async_context as async_context_module
    import llmdebug.capture as capture_module
    import llmdebug.error_categories as error_categories_module
    import llmdebug.git_context as git_context_module
    import llmdebug.log_capture as log_capture_module

    def _boom(*_args, **_kwargs):
        raise RuntimeError("forced failure")

    monkeypatch.setattr(error_categories_module, "categorize_exception", _boom)
    monkeypatch.setattr(capture_module.os.path, "relpath", _boom)
    monkeypatch.setattr(async_context_module, "is_coroutine_frame", _boom)
    monkeypatch.setattr(git_context_module, "get_git_context", _boom)
    monkeypatch.setattr(async_context_module, "get_async_context", _boom)
    monkeypatch.setattr(log_capture_module, "get_recent_logs", _boom)

    exc, tb = _exception_with_traceback()
    cfg = SnapshotConfig(
        out_dir=str(tmp_path),
        output_format="json",
        categorize_errors=True,
        include_git=True,
        include_async_context=True,
        capture_logs=True,
        debug=False,
    )
    capture_exception("warning_paths", exc, tb, cfg)

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None
    warnings = snapshot.get("_capture_warnings", [])
    assert any("error categorization failed" in w for w in warnings)
    assert any("relative path failed" in w for w in warnings)
    assert any("coroutine frame detection failed" in w for w in warnings)
    assert any("git context failed" in w for w in warnings)
    assert any("async context failed" in w for w in warnings)
    assert any("log capture failed" in w for w in warnings)


def test_collect_frames_warns_when_locals_count_fails(monkeypatch):
    """collect_frames should warn when locals length probing fails in meta mode."""
    import llmdebug.capture as capture_module

    class _BadLocals(dict):
        def __len__(self) -> int:
            raise RuntimeError("len failure")

    class _FakeCode:
        co_argcount = 0
        co_kwonlyargcount = 0
        co_varnames: tuple[str, ...] = ()
        co_flags = 0

    class _FakeFrame:
        f_locals = _BadLocals({"x": 1})
        f_globals = {"__name__": "fake.module"}
        f_code = _FakeCode()

    class _FakeTB:
        tb_frame = _FakeFrame()
        tb_next = None

    class _Extracted:
        filename = "fake.py"
        lineno = 1
        name = "fake"
        line = "raise RuntimeError()"

    monkeypatch.setattr(capture_module.traceback, "extract_tb", lambda _tb: [_Extracted()])
    cfg = SnapshotConfig(locals_mode="meta")
    warnings: list[str] = []

    frames = capture_module.collect_frames(_FakeTB(), cfg, warnings=warnings, redactors=[])
    assert frames
    assert any("locals count failed" in warning for warning in warnings)


def test_capture_exception_emits_debug_warnings(tmp_path, monkeypatch, capsys):
    """Debug mode should emit capture warnings to stderr."""
    import llmdebug as llmdebug_package

    monkeypatch.delattr(llmdebug_package, "__version__", raising=False)

    def _meta_failure():
        raise RuntimeError("meta failure")

    try:
        _meta_failure()
    except RuntimeError as exc:
        tb = exc.__traceback__
        cfg = SnapshotConfig(
            out_dir=str(tmp_path),
            output_format="json",
            locals_mode="meta",
            include_git=False,
            include_async_context=False,
            capture_logs=False,
            debug=True,
        )
        capture_exception("debug_warning_paths", exc, tb, cfg)

    stderr = capsys.readouterr().err
    assert "version detection failed" in stderr

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None
    warnings = snapshot.get("_capture_warnings", [])
    assert any("version detection failed" in w for w in warnings)


def test_decorator_captures_exception(tmp_path):
    """Test that decorator captures exception and still raises."""

    @debug_snapshot(out_dir=str(tmp_path))
    def failing_func():
        x = [1, 2, 3]  # noqa: F841 - intentional for testing locals capture
        raise ValueError("test error")

    with pytest.raises(ValueError, match="test error"):
        failing_func()

    # Check snapshot was created
    snapshots = [path for path in tmp_path.glob("*.json") if path.name != "latest.json"]
    assert len(snapshots) == 1


def test_context_manager_captures_exception(tmp_path):
    """Test that context manager captures exception."""
    with pytest.raises(RuntimeError), snapshot_section("test_section", out_dir=str(tmp_path)):
        data = {"key": "value"}  # noqa: F841 - intentional for testing locals capture
        raise RuntimeError("context error")

    snapshots = list(tmp_path.glob("*test_section*.json"))
    assert len(snapshots) == 1


def test_no_exception_no_snapshot(tmp_path):
    """Test that no snapshot is created when no exception."""

    @debug_snapshot(out_dir=str(tmp_path))
    def passing_func():
        return 42

    result = passing_func()
    assert result == 42

    snapshots = list(tmp_path.glob("*.json"))
    assert len(snapshots) == 0


def test_snapshot_contains_correct_structure(tmp_path):
    """Test that snapshot JSON contains all expected fields."""

    @debug_snapshot(out_dir=str(tmp_path))
    def failing_with_locals():
        my_list = [1, 2, 3]  # noqa: F841
        my_dict = {"key": "value"}  # noqa: F841
        my_number = 42  # noqa: F841
        raise ValueError("test error message")

    with pytest.raises(ValueError):
        failing_with_locals()

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    # Check top-level structure
    assert snapshot["name"] == "failing_with_locals"
    assert "timestamp_utc" in snapshot
    assert snapshot["exception"]["type"] == "ValueError"
    assert snapshot["exception"]["qualified_type"] == "builtins.ValueError"
    assert snapshot["exception"]["message"] == "test error message"
    assert "traceback" in snapshot
    assert "frames" in snapshot
    assert snapshot["crash_frame_index"] == 0
    assert "env" in snapshot

    # Check frames structure (crash site should be first)
    assert len(snapshot["frames"]) > 0
    crash_frame = snapshot["frames"][0]
    assert "file" in crash_frame
    assert "line" in crash_frame
    assert "function" in crash_frame
    assert crash_frame["function"] == "failing_with_locals"
    assert "locals" in crash_frame

    # Check that locals were captured
    locals_dict = crash_frame["locals"]
    assert "my_list" in locals_dict
    assert locals_dict["my_list"] == [1, 2, 3]
    assert "my_dict" in locals_dict
    assert "my_number" in locals_dict
    assert locals_dict["my_number"] == 42


def test_capture_writes_debug_session_envelope(tmp_path):
    """Captured files use the versioned DebugSession envelope on disk."""

    @debug_snapshot(out_dir=str(tmp_path), output_format="json")
    def failing_for_envelope():
        raise ValueError("envelope test")

    with pytest.raises(ValueError, match="envelope test"):
        failing_for_envelope()

    latest = tmp_path / "latest.json"
    raw = json.loads(latest.read_text(encoding="utf-8"))

    assert raw["schema_version"] == "2.0"
    assert raw["kind"] == "llmdebug.debug_session"
    assert raw["session"]["name"] == "failing_for_envelope"
    assert raw["snapshot"]["exception"]["type"] == "ValueError"
    assert raw["snapshot"]["frames"][0]["function"] == "failing_for_envelope"


def test_snapshot_captures_array_shapes(tmp_path):
    """Test that numpy arrays are summarized with shape info."""
    pytest.importorskip("numpy")
    import numpy as np

    @debug_snapshot(out_dir=str(tmp_path))
    def failing_with_array():
        arr = np.zeros((10, 20, 30))  # noqa: F841
        raise RuntimeError("array error")

    with pytest.raises(RuntimeError):
        failing_with_array()

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    crash_frame = snapshot["frames"][0]
    arr_info = crash_frame["locals"]["arr"]

    # Should have array summary, not raw data
    assert "__array__" in arr_info
    assert arr_info["shape"] == [10, 20, 30]
    assert arr_info["dtype"] == "float64"


def test_locals_mode_none_skips_locals(tmp_path):
    """Test that locals_mode='none' doesn't capture locals."""

    @debug_snapshot(out_dir=str(tmp_path), locals_mode="none")
    def failing_no_locals():
        secret = "password123"  # noqa: F841
        raise ValueError("error")

    with pytest.raises(ValueError):
        failing_no_locals()

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    crash_frame = snapshot["frames"][0]
    assert "locals" not in crash_frame


def test_locals_mode_meta_captures_metadata(tmp_path):
    """Test that locals_mode='meta' captures locals_meta only."""

    @debug_snapshot(out_dir=str(tmp_path), locals_mode="meta")
    def failing_meta():
        secret = "password123"  # noqa: F841
        items = [1, 2, 3]  # noqa: F841
        raise ValueError("error")

    with pytest.raises(ValueError):
        failing_meta()

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    crash_frame = snapshot["frames"][0]
    assert "locals" not in crash_frame
    assert "locals_meta" in crash_frame


def test_source_mode_crash_only(tmp_path):
    """Test that source is captured only for crash frame."""

    @debug_snapshot(out_dir=str(tmp_path), frames=2, source_mode="crash_only")
    def outer():
        def inner():
            raise RuntimeError("boom")

        inner()

    with pytest.raises(RuntimeError):
        outer()

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    assert len(snapshot["frames"]) == 2
    crash_frame = snapshot["frames"][0]
    parent_frame = snapshot["frames"][1]
    assert "source" in crash_frame
    assert "source" not in parent_frame


def test_exception_args_and_notes(tmp_path):
    """Test that exception args and notes are captured."""

    @debug_snapshot(out_dir=str(tmp_path))
    def failing_with_args():
        exc = ValueError("a", "b")
        if hasattr(exc, "add_note"):
            exc.add_note("note")  # pyright: ignore[reportAttributeAccessIssue]
        raise exc

    with pytest.raises(ValueError):
        failing_with_args()

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    exc = snapshot["exception"]
    assert exc["args"] == ["a", "b"]
    if hasattr(BaseException(), "add_note"):
        assert "notes" in exc


def test_locals_mode_invalid_raises():
    """Test that invalid locals_mode values raise a ValueError."""
    with pytest.raises(ValueError, match="locals_mode must be 'safe', 'meta', or 'none'"):
        debug_snapshot(locals_mode="invalid")  # type: ignore[arg-type]


def test_include_modules_filters_frames(tmp_path):
    """Test that include_modules filters non-matching frames."""

    # Use a module prefix that won't match our test module
    @debug_snapshot(out_dir=str(tmp_path), include_modules=["nonexistent_module"])
    def outer():
        def inner():
            raise ValueError("filtered test")

        inner()

    with pytest.raises(ValueError):
        outer()

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    # Should only have the crash frame (always included) since no module matches
    # The crash frame is always kept regardless of filter
    frames = snapshot["frames"]
    assert len(frames) >= 1

    # Crash frame should be present at index 0
    assert frames[0]["function"] == "inner"


def test_include_modules_matches_prefix(tmp_path):
    """Test that module prefix matching works correctly."""

    # Use the actual test module prefix which should match
    @debug_snapshot(out_dir=str(tmp_path), frames=5, include_modules=["tests", "test_"])
    def outer():
        def middle():
            def inner():
                raise RuntimeError("prefix test")

            inner()

        middle()

    with pytest.raises(RuntimeError):
        outer()

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    # All frames should be from our test module
    frames = snapshot["frames"]
    assert len(frames) >= 1
    # Crash frame is always included
    assert frames[0]["function"] == "inner"


def test_include_modules_none_captures_all(tmp_path):
    """Test that include_modules=None captures all frames (default behavior)."""

    @debug_snapshot(out_dir=str(tmp_path), frames=5, include_modules=None)
    def failing():
        raise ValueError("all frames test")

    with pytest.raises(ValueError):
        failing()

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None
    assert len(snapshot["frames"]) >= 1


def test_exception_chain_depth_configurable(tmp_path):
    """Test that max_exception_depth controls exception chain traversal."""

    @debug_snapshot(out_dir=str(tmp_path), max_exception_depth=3)
    def deep_chain():
        try:
            try:
                try:
                    raise ValueError("level 0")
                except ValueError as e:
                    raise TypeError("level 1") from e
            except TypeError as e:
                raise RuntimeError("level 2") from e
        except RuntimeError as e:
            raise KeyError("level 3") from e

    with pytest.raises(KeyError):
        deep_chain()

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    exc = snapshot["exception"]
    assert exc["type"] == "KeyError"

    # With depth=3, we should see the cause chain
    assert "cause" in exc
    assert exc["cause"]["type"] == "RuntimeError"
    assert "cause" in exc["cause"]
    assert exc["cause"]["cause"]["type"] == "TypeError"


def test_exception_chain_depth_one(tmp_path):
    """Test that max_exception_depth=1 stops at first exception."""

    @debug_snapshot(out_dir=str(tmp_path), max_exception_depth=1)
    def shallow_chain():
        try:
            raise ValueError("original")
        except ValueError as e:
            raise RuntimeError("wrapped") from e

    with pytest.raises(RuntimeError):
        shallow_chain()

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    exc = snapshot["exception"]
    assert exc["type"] == "RuntimeError"

    # With depth=1, cause should not have further cause
    # (depth 1 means we capture the exception itself but no chain traversal)
    # Actually checking the implementation: depth starts at 0, increments to 1 for cause
    # So with max_depth=1, cause at depth=1 won't recurse further
    if "cause" in exc:
        # The cause is captured but won't have its own cause/context
        assert "cause" not in exc["cause"] or exc["cause"].get("cause") is None


def test_config_validation_max_exception_depth():
    """Test that max_exception_depth validation works."""
    with pytest.raises(ValueError, match="max_exception_depth must be >= 1"):
        debug_snapshot(max_exception_depth=0)


def test_config_validation_lock_timeout():
    """Test that lock_timeout validation works."""
    with pytest.raises(ValueError, match="lock_timeout must be >= 0"):
        debug_snapshot(lock_timeout=-1)


def test_config_validation_log_max_records():
    """Test that log_max_records validation works."""
    with pytest.raises(ValueError, match="log_max_records must be >= 0"):
        debug_snapshot(log_max_records=-1)


# ============================================================================
# Function Arguments Tests
# ============================================================================


def test_function_args_captured(tmp_path):
    """Test that function arguments are captured separately from locals."""

    @debug_snapshot(out_dir=str(tmp_path), include_args=True)
    def func_with_args(a, b, c=10):
        local_var = a + b
        raise ValueError(f"Sum is {local_var}")

    with pytest.raises(ValueError):
        func_with_args(1, 2, c=20)

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    # Find the crash frame (should be func_with_args)
    crash_frame = snapshot["frames"][0]
    assert crash_frame["function"] == "func_with_args"

    # Should have args and arg_names
    assert "args" in crash_frame
    assert "arg_names" in crash_frame

    # Check arg_names
    assert crash_frame["arg_names"] == ["a", "b", "c"]

    # Check arg values
    args = crash_frame["args"]
    assert args["a"] == 1
    assert args["b"] == 2
    assert args["c"] == 20


def test_function_args_disabled(tmp_path):
    """Test that function arguments are not captured when disabled."""

    @debug_snapshot(out_dir=str(tmp_path), include_args=False)
    def func_with_args(a, b):
        raise ValueError("test")

    with pytest.raises(ValueError):
        func_with_args(1, 2)

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    crash_frame = snapshot["frames"][0]

    # Should not have args or arg_names
    assert "args" not in crash_frame
    assert "arg_names" not in crash_frame


def test_function_args_with_varargs(tmp_path):
    """Test that *args and **kwargs are captured."""

    @debug_snapshot(out_dir=str(tmp_path), include_args=True)
    def func_with_varargs(a, *args, **kwargs):
        raise ValueError("test")

    with pytest.raises(ValueError):
        func_with_varargs(1, 2, 3, x=10, y=20)

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    crash_frame = snapshot["frames"][0]
    assert "args" in crash_frame
    assert "arg_names" in crash_frame

    # Check arg_names includes *args and **kwargs markers
    arg_names = crash_frame["arg_names"]
    assert "a" in arg_names
    assert any("*args" in name for name in arg_names)
    assert any("**kwargs" in name for name in arg_names)

    # Check values (tuples become lists in JSON serialization)
    args = crash_frame["args"]
    assert args["a"] == 1
    assert args["args"] == [2, 3]
    assert args["kwargs"] == {"'x'": 10, "'y'": 20}  # Keys get repr'd


def test_function_args_with_self(tmp_path):
    """Test that self is captured as an argument for methods."""

    class MyClass:
        def __init__(self, value):
            self.value = value

        @debug_snapshot(out_dir=str(tmp_path), include_args=True)
        def method(self, x):
            raise ValueError("test")

    obj = MyClass(42)
    with pytest.raises(ValueError):
        obj.method(10)

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    crash_frame = snapshot["frames"][0]
    assert "args" in crash_frame
    assert "arg_names" in crash_frame

    # Check that self is in arg_names
    assert "self" in crash_frame["arg_names"]
    assert "x" in crash_frame["arg_names"]

    # Check values
    args = crash_frame["args"]
    assert args["x"] == 10
    # self should be serialized as an object
    assert "__type__" in args["self"] or "value" in str(args["self"])


def test_function_args_with_keyword_only(tmp_path):
    """Test that keyword-only arguments are captured."""

    @debug_snapshot(out_dir=str(tmp_path), include_args=True)
    def func_with_kwonly(a, b, *, kwonly1, kwonly2=None):
        raise ValueError("test")

    with pytest.raises(ValueError):
        func_with_kwonly(1, 2, kwonly1="required", kwonly2="optional")

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    crash_frame = snapshot["frames"][0]
    assert "args" in crash_frame
    assert "arg_names" in crash_frame

    # Check all arg names are captured (including keyword-only)
    arg_names = crash_frame["arg_names"]
    assert "a" in arg_names
    assert "b" in arg_names
    assert "kwonly1" in arg_names
    assert "kwonly2" in arg_names

    # Check values
    args = crash_frame["args"]
    assert args["a"] == 1
    assert args["b"] == 2
    assert args["kwonly1"] == "required"
    assert args["kwonly2"] == "optional"


def test_function_args_with_kwonly_and_varargs(tmp_path):
    """Test complex signature: positional, *args, keyword-only, **kwargs."""

    @debug_snapshot(out_dir=str(tmp_path), include_args=True)
    def complex_func(a, *args, kwonly, **kwargs):
        raise ValueError("test")

    with pytest.raises(ValueError):
        complex_func(1, 2, 3, kwonly="kw", extra="val")

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    crash_frame = snapshot["frames"][0]
    arg_names = crash_frame["arg_names"]

    # Check all arg types are captured in order
    assert "a" in arg_names
    assert "kwonly" in arg_names
    assert any("*args" in name for name in arg_names)
    assert any("**kwargs" in name for name in arg_names)

    # Check values
    args = crash_frame["args"]
    assert args["a"] == 1
    assert args["kwonly"] == "kw"
    assert args["args"] == [2, 3]


# ============================================================================
# Error Categorization Tests
# ============================================================================


def test_error_categorization_in_snapshot(tmp_path):
    """Test that error categorization is included in snapshot."""

    @debug_snapshot(out_dir=str(tmp_path), categorize_errors=True)
    def shape_error():
        raise ValueError("shape mismatch: expected (10,) got (20,)")

    with pytest.raises(ValueError):
        shape_error()

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    # Should have error_category in exception
    exc = snapshot["exception"]
    assert "error_category" in exc
    assert exc["error_category"]["category"] == "shape_mismatch"
    assert "suggestion" in exc["error_category"]


def test_error_categorization_disabled(tmp_path):
    """Test that error categorization is not included when disabled."""

    @debug_snapshot(out_dir=str(tmp_path), categorize_errors=False)
    def some_error():
        raise ValueError("shape mismatch")

    with pytest.raises(ValueError):
        some_error()

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    # Should not have error_category
    exc = snapshot["exception"]
    assert "error_category" not in exc


# ============================================================================
# Git Context Tests
# ============================================================================


def test_git_context_in_snapshot(tmp_path):
    """Test that git context is included in snapshot."""

    @debug_snapshot(out_dir=str(tmp_path), include_git=True)
    def failing():
        raise ValueError("test")

    with pytest.raises(ValueError):
        failing()

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    # Should have git context since we're running from a git repo
    if "git" in snapshot:
        assert "commit" in snapshot["git"]
        assert "branch" in snapshot["git"]


def test_git_context_disabled(tmp_path):
    """Test that git context is not included when disabled."""

    @debug_snapshot(out_dir=str(tmp_path), include_git=False)
    def failing():
        raise ValueError("test")

    with pytest.raises(ValueError):
        failing()

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    # Should not have git context
    assert "git" not in snapshot


# ============================================================================
# Config Serialization Tests
# ============================================================================


def test_new_config_fields_serialized(tmp_path):
    """Test that new config fields are included in capture_config."""

    @debug_snapshot(
        out_dir=str(tmp_path),
        include_git=True,
        include_array_stats=True,
        include_args=True,
        categorize_errors=True,
        include_async_context=True,
        capture_logs=False,
        log_max_records=50,
    )
    def failing():
        raise ValueError("test")

    with pytest.raises(ValueError):
        failing()

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None

    cfg = snapshot["capture_config"]
    assert cfg["include_git"] is True
    assert cfg["include_array_stats"] is True
    assert cfg["include_args"] is True
    assert cfg["categorize_errors"] is True
    assert cfg["include_async_context"] is True
    assert cfg["capture_logs"] is False
    assert cfg["log_max_records"] == 50
    assert cfg["lock_timeout"] == 5.0
    assert cfg["output_format"] == "json_compact"


def test_redaction_profile_serialized(tmp_path):
    @debug_snapshot(
        out_dir=str(tmp_path),
        redaction_profile="prod",
    )
    def failing():
        raise ValueError("password=secret123")

    with pytest.raises(ValueError):
        failing()

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None
    cfg = snapshot["capture_config"]
    assert cfg["redaction_profile"] == "prod"
    assert cfg["redact_traceback"] is True
    assert cfg["redact_exception_strings"] is True
    assert len(cfg["redact"]) > 0


def test_exception_and_traceback_redaction_opt_in(tmp_path):
    @debug_snapshot(
        out_dir=str(tmp_path),
        redact=(r"token=\w+",),
        redact_traceback=True,
        redact_exception_strings=True,
    )
    def failing():
        raise ValueError("token=abcdef")

    with pytest.raises(ValueError):
        failing()

    snapshot = get_latest_snapshot(str(tmp_path))
    assert snapshot is not None
    assert "[REDACTED]" in snapshot["exception"]["message"]
    assert "token=abcdef" not in snapshot["exception"]["message"]
    assert "[REDACTED]" in snapshot["traceback"]
    assert "token=abcdef" not in snapshot["traceback"]



from sys import setrecursionlimit, stdin

setrecursionlimit(10**6)
readline = stdin.readline
M998 = 998244353
M007 = 10**9 + 7
INF = 10**18
mulint = lambda: map(int, readline().split())
anint = lambda: int(readline())
astr = lambda: readline().rstrip()
from bisect import bisect_right

N, K = mulint()
A = list(mulint())

L, R = A[:K], A[K:]

M = [R[0]]
V = [0]
for i in range(1, N - K):
    if R[i] > M[-1]:
        M.append(R[i])
        V.append(i)

V.append(INF)
m = INF
for i in range(K):
    j = bisect_right(M, L[i])
    m = min(m, V[j] + (K - i - 1) + 1)
print(m)



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='5\n00011\n3 9 2 6 4\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '7\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='4\n1001\n1 2 3 4\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '0\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='11\n11111100111\n512298012 821282085 543342199 868532399 690830957 973970164 928915367 954764623 923012648 540375785 925723427\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '2286846953\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2\n00\n1 2\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '0\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2\n10\n3 4\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '3\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



from __future__ import annotations

from dataclasses import dataclass
from pathlib import Path

from .base import Patcher, PatchResult


@dataclass(frozen=True)
class NullPatcher(Patcher):
    name: str = "null"

    def propose_patch(self, *, prompt: str, context_dir: Path, cwd: Path) -> PatchResult:
        return PatchResult(diff=None, meta={"reason": "null_patcher"})



# B
n = int(input())
a = list(map(int, input().split()))
# n = 4
# a = [2, 5, 1, 2]
b = []
i_bef = 0
# print(a)
for i in a:
    print(i)
    if i_bef == 0:
        b.append(i)
        i_bef = i
        continue
    dif = i - i_bef
    # print("dif:", dif)
    if abs(dif) > 1:
        if dif > 0:
            for j in range(1, abs(dif)):
                # print("j", j)
                b.append(i_bef + j)
            b.append(i)
        else:
            for j in range(1, abs(dif)):
                # print("j", j)
                b.append(i_bef - j)
            b.append(i)
    else:
        b.append(i)
    i_bef = i
    # print("i_bef", i_bef)
print(*b)



n = int(input())
a = list(map(int, input().split()))
ikeru = [[] for i in range(n)]
for i in range(n - 1):
    u, v = map(int, input().split())
    u -= 1
    v -= 1
    ikeru[u].append(v)
    ikeru[v].append(u)


def canreach(x):
    # x以上に到達可能か？
    # 部分木DP
    mada = [~0, 0]
    tansaku = [0] * n
    tansaku[0] = 1
    dp = [0] * n
    while mada:
        i = mada.pop()
        if i >= 0:
            for j in ikeru[i]:
                if tansaku[j] == 0:
                    tansaku[j] = 1
                    mada.append(~j)
                    mada.append(j)
        else:
            i = ~i
            tmp = 0
            for j in ikeru[i]:
                if tansaku[j] == 2:
                    tmp += dp[j]
            tmp = max(0, tmp - 1)
            if i >= 1:
                if a[i - 1] >= x:
                    tmp += 1
            dp[i] = tmp
            tansaku[i] = 2
    if dp[0] >= 1:
        return True
    return False


suki = 10**9 + 5
kirai = -1
while suki - kirai > 1:
    targ = (suki + kirai) // 2
    if canreach(targ):
        kirai = targ
    else:
        suki = targ

print(kirai)



K = int(input())
S = list(map(int, input().split()))
T = list(map(int, input().split()))

S[0] += 2 * K
S[1] += 2 * K
T[0] += 2 * K
T[1] += 2 * K


distX = T[0] - S[0]
distY = T[1] - S[1]
bigM = max(distX, -distX) + max(distY, -distY)

if K == 1:
    print(bigM)
    exit()


if (S[0] // K + S[1] // K) % 2 == 0:
    tileS = "small"
else:
    tileS = "large"


if (T[0] // K + T[1] // K) % 2 == 0:
    tileT = "small"
else:
    tileT = "large"

lstS = []
lstT = []

if tileS == "large":
    lstS.append([S, 0])
else:
    lstS.append([[S[0] - K, S[1]], S[0] - K * (S[0] // K) + 1])
    lstS.append([[S[0] + K, S[1]], K * (S[0] // K + 1) - S[0]])
    lstS.append([[S[0], S[1] - K], S[1] - K * (S[1] // K) + 1])
    lstS.append([[S[0], S[1] + K], K * (S[1] // K + 1) - S[1]])

if tileT == "large":
    lstT.append([T, 0])
else:
    lstT.append([[T[0] - K, T[1]], T[0] - K * (T[0] // K) + 1])
    lstT.append([[T[0] + K, T[1]], K * (T[0] // K + 1) - T[0]])
    lstT.append([[T[0], T[1] - K], T[1] - K * (T[1] // K) + 1])
    lstT.append([[T[0], T[1] + K], K * (T[1] // K + 1) - T[1]])

res = bigM
# print(lstS,lstT)
for ss in lstS:
    s, dist0 = ss
    if dist0 < 0:
        dist0 *= -1
    blS = [K * (s[0] // K), K * (s[1] // K)]
    for tt in lstT:
        t, dist1 = tt
        if dist1 < 0:
            dist1 *= -1
        dist1
        blT = [K * (t[0] // K), K * (t[1] // K)]

        blockX = (blT[0] - blS[0]) // K
        blockY = (blT[1] - blS[1]) // K
        dist = 2 * max(blockX, blockY, -blockX, -blockY) + dist0 + dist1
        if dist < res:
            # print("#",dist0,dist1,blockX,blockY,blS,blT,s,t)
            res = dist
        if K == 2:
            blockX = max(blockX, -blockX)
            blockY = max(blockY, -blockY)
            if blockX > blockY:
                blockX, blockY = blockY, blockX
            dist = 2 * blockX + 3 * (blockY - blockX) + dist0 + dist1
            if dist < res:
                res = dist

print(res)



N = int(input())
P = list(map(int, input().split()))

for i in range(N):
    if P[-i] > P[-i - 1]:
        continue
    else:
        num = P[-i - 1]
        a = i
        break

A = P[N - a - 1 :]  # 変化させる部分
A.sort()
B = []

B.append(A[A.index(num) - 1])  # 変化する数字の一番左
A.pop(A.index(num) - 1)
A.sort(reverse=True)  # Bの後ろは逆順

print(*P[: N - a - 1] + B + A)



N, D = map(int, input().split())
A = [int(i) for i in input().split()]

mod = 998244353
S = 1 << (2 * D + 2)
dp = [[0] * (S) for _ in range(N + 1)]
dp[0][(1 << (D + 1)) - 1] = 1
for i, a in enumerate(A):
    if a > -1:
        for s in range(S):
            if s & 1 == 0:
                continue
            t = s >> 1
            diff = a - (i + 1) + D
            if t >> diff & 1:
                continue
            dp[i + 1][t | (1 << diff)] += dp[i][s]
            dp[i + 1][t | (1 << diff)] %= mod
    else:
        for s in range(S):
            if s & 1 == 0:
                continue
            t = s >> 1
            for diff in range(0, 2 * D + 2):
                if t >> diff & 1:
                    continue
                dp[i + 1][t | (1 << diff)] += dp[i][s]
                dp[i + 1][t | (1 << diff)] %= mod
# for i in range(N+1):
#     print(dp[i][:30])
print(dp[-1][(1 << (D + 1)) - 1])



from collections import Counter, defaultdict
# from sortedcontainers import SortedSet, SortedList

n = int(input())
arr = list(map(int, input().split()))

dp = [0] * (n + 1)
dp[0] = 1
for i in range(n):
    l, r = i, i + 1
    while l > 0 and arr[l - 1] < arr[i]:
        l -= 1
    while r < n and arr[r] < arr[i]:
        r += 1
    for k in range(l, r):
        dp[k + 1] += dp[k]
print(dp[n])



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='4\n1\n7 2\n2\n2 2\n5 1\n1\n5 1\n2\n2 1\n7 1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '3\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='1\n1\n998244353 1000000000\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2\n1\n3 7\n3\n3 10\n5 6\n11 1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '2\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='5\n1\n3 6\n2\n5 8\n11 8\n2\n7 3\n11 8\n1\n2 2\n1\n2 9\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '5\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2\n3\n3 2\n5 5\n7 4\n3\n3 10\n7 3\n11 6\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '2\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



N, Q = map(int, input().split())

T = [2] * N
for i in range(Q):
    c, x = map(int, input().split())

    if c == 1:
        T[x - 1] -= 1
    elif c == 2:
        T[x - 1] -= 2
    else:
        if T[x - 1] == 0:
            print("Yes")
        else:
            print("No")



N, M = map(int, input().split())
goal = input().split()
nutrition = []
check = []
for i in range(N):
    nutrition.append(input().split())


def sum_nut(N, nut_num, goal, check):
    sum_n = []
    for i in range(N):
        sum_n.append(int(nutrition[i][nut_num]))
    if int(goal[nut_num]) < sum(sum_n):
        check.append(1)
    else:
        check.append(0)


for i in range(M):
    sum_nut(N, i, goal, check)
if sum(check) == M:
    print("Yes")
else:
    print("No")



# B - Yellow and Red Card
def main():
    N, Q = map(int, input().split())
    cards = [0] * (N + 1)

    for _ in range(Q):
        c, x = map(int, input().split())

        if c == 1:
            cards[x] += 1
        elif c == 2:
            cards[x] += 2
        else:
            if cards[x] == 2:
                print("Yes")
            else:
                print("No")


if __name__ == "__main__":
    main()



n = int(input())
l = list(input())

lacnt = []
lbcnt = []
a = 0
b = 0
for i in l:
    if i == "A":
        a += 1
    if i == "B":
        b += 1
    lacnt.append(a)
    lbcnt.append(b)

for i in range(1, n + 1):
    if lacnt[i] >= lbcnt[i]:
        print("Arice")
    else:
        print("Bob")



# Perfect Bus
def calc(N, A):
    start = 0
    total = 0
    for i in A:
        total += i
        if -start > total:
            start = -total
        print("total: " + str(total))
        print("start: " + str(start))
    return start + total


def main():
    N = int(input())
    A = [int(i) for i in input().split()]
    print(calc(N, A))


if __name__ == "__main__":
    main()



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='3\n1 4 8\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '2\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='4\n5 10 15 20\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='10\n3785 5176 10740 7744 3999 3143 9028 2822 4748 6888\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2\n70 51\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='3\n85 51 47\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



N, M = map(int, input().split())
S = [list(input()) for _ in range(N)]

ans = M + 10

for bit in range(1 << N):  # 訪れるポップコーン売り場の選び方＝bit
    store = []
    for i in range(N):  # N個の売り場について
        if bit >> i & 1:  # bitのi番目のビットが1かどうか pythonで1はTrue, 0はFalse
            store.append(i)  # bitで1だった売り場のindexをstoreに入れる

    data = [0] * M
    for s_i in store:  # storeに格納された売り場のindex=s_iについて
        for j, s_j in enumerate(S[s_i]):
            if s_j == "o":  # s_i番目の売り場のj番目の要素s_jがoだったら
                data[j] == 1

    if data == [1] * M:
        ans = min(ans, len(store))

print(ans)



from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools


class Solution:
    def kthLargestNumber(self, nums: List[str], k: int) -> str:
        ls = []
        for i in nums:
            ls.append(int(i))
        sorted_ = sorted(ls)
        return str(sorted_[k])



"""Configuration dataclass for snapshot capture."""

from __future__ import annotations

from dataclasses import dataclass, field
from re import Pattern
from typing import Literal

SourceMode = Literal["all", "crash_only", "none"]
LocalsMode = Literal["safe", "meta", "none"]
OutputFormat = Literal["json", "json_compact", "toon"]
DetailLevel = Literal["crash", "full", "context"]
RedactionProfile = Literal["dev", "ci", "prod"]


@dataclass(frozen=True)
class SnapshotConfig:
    """Configuration for debug snapshot capture."""

    out_dir: str = ".llmdebug"
    frames: int = 5
    source_context: int = 3
    source_mode: SourceMode = "all"
    locals_mode: LocalsMode = "safe"
    max_str: int = 500
    max_items: int = 50
    redaction_profile: RedactionProfile | None = None
    redact: tuple[str | Pattern[str], ...] = field(default_factory=tuple)
    redact_keys: bool = False  # Redact dict keys as well as values (can collapse keys)
    redact_traceback: bool = False  # Redact traceback string payloads
    redact_exception_strings: bool = False  # Redact exception message/args/notes strings
    include_env: bool = True
    debug: bool = False
    max_snapshots: int = 50  # 0 = unlimited
    include_modules: tuple[str, ...] | None = None  # Filter frames by module prefix
    max_exception_depth: int = 5  # Exception chain recursion limit
    lock_timeout: float = 5.0  # Seconds to wait for file lock
    # New feature flags
    include_git: bool = True  # Capture git commit/branch/dirty status
    include_array_stats: bool = False  # Compute min/max/mean/std for arrays
    include_args: bool = True  # Separate function arguments from locals
    categorize_errors: bool = True  # Auto-classify errors with suggestions
    include_async_context: bool = True  # Capture asyncio task info
    capture_logs: bool = False  # Capture recent log records
    log_max_records: int = 20  # Max log records to capture
    output_format: OutputFormat = "json_compact"
    include_coverage: bool = True  # Include coverage data from pytest-cov

    def __post_init__(self) -> None:
        if self.output_format not in {"json", "json_compact", "toon"}:
            raise ValueError("output_format must be 'json', 'json_compact', or 'toon'")
        if self.locals_mode not in {"safe", "meta", "none"}:
            raise ValueError("locals_mode must be 'safe', 'meta', or 'none'")
        if self.source_mode not in {"all", "crash_only", "none"}:
            raise ValueError("source_mode must be 'all', 'crash_only', or 'none'")
        if self.frames < 1:
            raise ValueError("frames must be >= 1")
        if self.max_str < 13:
            raise ValueError("max_str must be >= 13 (12-char truncation marker + 1)")
        if self.max_items < 1:
            raise ValueError("max_items must be >= 1")
        if self.max_snapshots < 0:
            raise ValueError("max_snapshots must be >= 0 (0 = unlimited)")
        if self.max_exception_depth < 1:
            raise ValueError("max_exception_depth must be >= 1")
        if self.lock_timeout < 0:
            raise ValueError("lock_timeout must be >= 0")
        if self.log_max_records < 0:
            raise ValueError("log_max_records must be >= 0")
        if self.redaction_profile not in {None, "dev", "ci", "prod"}:
            raise ValueError("redaction_profile must be one of: dev, ci, prod, or None")



class Input_kyopro:
    def II(self):
        return int(input())

    def MI(self):
        return map(int, input().split())

    def MS(self):
        return map(str, input().split())

    def LMI(self):
        return list(self.MI())

    def LMS(self):
        return list(self.MS())

    def LLI(self, N):
        return [self.LMI() for _ in range(N)]

    def LLS(self, N):
        return [self.LMS() for _ in range(N)]

    def LS(self, N):
        return [input() for _ in range(N)]

    def LSL(self, N):
        return [list(input()) for _ in range(N)]

    def LI(self, N):
        return [self.II() for _ in range(N)]


I = Input_kyopro()
# 入力
from collections import deque

H, W, T = I.MI()
a = I.LSL(H)
dx = [1, 0, -1, 0]
dy = [0, 1, 0, -1]
start = [0, 0]
g = [0, 0]
ls = []
for i in range(H):
    for j in range(W):
        if a[i][j] == "S":
            s = [i, j]
        if a[i][j] == "G":
            g = [i, j]
        if a[i][j] == "o":
            ls.append([i, j])
cnt = len(ls)
d = [[[0] * W for _ in range(H)] for _ in range(cnt)]


def dist(i, j):
    res = [[float("inf")] * W for _ in range(H)]
    res[i][j] = 0
    q = deque()
    q.append([i, j])
    while q:
        i, j = q.popleft()
        for k in range(4):
            if 0 <= i + dx[k] < H and 0 <= j + dy[k] < W:
                if res[i + dx[k]][j + dy[k]] != float("inf") or a[i + dx[k]][j + dy[k]] == "#":
                    continue
                res[i + dx[k]][j + dy[k]] = res[i][j] + 1
                q.append([i + dx[k], j + dy[k]])
    return res


for i in range(cnt):
    d[i] = dist(ls[i][0], ls[i][1])
dp = [[float("inf")] * (cnt) for _ in range(1 << cnt)]
for i in range(cnt):
    dp[1 << i][i] = d[i][start[0]][start[1]]
for s in range(1, 1 << cnt):
    for last in range(cnt):
        if dp[s][last] == float("inf"):
            continue
        for nx in range(cnt):
            if s >> nx & 1:
                continue
            dp[s | 1 << nx][nx] = min(
                dp[s | 1 << nx][nx], dp[s][last] + d[last][ls[nx][0]][ls[nx][1]]
            )
ans = -1
if dist(start[0], start[1])[g[0]][g[1]] <= T:
    ans = 0
for s in range(1, 1 << cnt):
    for last in range(cnt):
        if dp[s][last] + d[last][g[0]][g[1]] <= T:
            now = 0
            for i in range(cnt):
                if s >> i & 1:
                    now += 1
            ans = max(ans, now)
print(ans)



x, y, z = map(int, input().split())

if y < 0 < x or y > 0 > x:
    print(abs(x))
elif 0 < y < x or 0 > y > x:
    if 0 < y < z or 0 > y > z:
        print(-1)
    elif 0 < z < x or 0 > z > x:
        print(abs(x))
    else:
        print(abs(x) + abs(z) * 2)



N, M = map(int, input().split())
S = input()
T = input()

if S == T:
    print(0)
else:
    atama = T.find(S) == 0
    sippo = T.find(S) == len(T) - len(S)
    if atama and sippo:
        print(0)
    elif atama:
        print(1)
    elif sippo:
        print(2)
    else:
        print(3)



T = int(input())


def calc(a, b, c):
    a, b = max(a, b), min(a, b)

    if a == b:
        # 成功
        return a
    elif (a - b) % 3 == 0 and (a - b) // 3 <= c:
        return a
    else:
        return -1


for _ in range(T):
    R, G, B = [int(x) for x in input().split()]
    l = [
        calc(R, G, B),
        calc(R, B, G),
        calc(G, B, R),
    ]
    if len([x for x in l if x > -1]):
        print(min([x for x in l if x > -1]))
    else:
        print(-1)



from buggy import Solution


def test_case_0():
    sol = Solution()
    result = sol.minimumPartition("165462", 60)
    assert result == 4


def test_case_1():
    sol = Solution()
    result = sol.minimumPartition("238182", 5)
    assert result == -1



from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools


class Solution:
    def tribonacci(self, n: int) -> int:
        if n == 0:
            return 0
        d = [0] * (3)
        d[0] = 0
        d[1] = d[2] = 1
        for i in range(3, n + 1):
            d.append(sum(d[1:]))
            d.pop(0)
        return d[2]



import sys

# sys.setrecursionlimit(100000)
input = lambda: sys.stdin.readline().strip()
# write=lambda x:sys.stdout.write(str(x)+'\n')

# from decimal import Decimal
# from random import randint
# from copy import deepcopy
from collections import deque, Counter

# from heapq import heapify,heappush,heappop
# from bisect import bisect_left,bisect,insort
from math import (
    inf,
    sqrt,
    gcd,
    lcm,
    pow,
    ceil,
    floor,
    log,
    log2,
    log10,
    pi,
    sin,
    cos,
    tan,
    asin,
    acos,
    atan,
)
# from functools import cmp_to_key
# from itertools import permutations,combinations


def solve():
    n = int(input())
    if n < 1e3:
        return n
    elif n < 1e4:
        return n // 10 * 10
    elif n < 1e5:
        return n // 100 * 100
    elif n < 1e6:
        return n // 1000 * 1000
    elif n < 1e7:
        return n // 10000 * 10000
    elif n < 1e8:
        return n // 100000 * 100000
    elif n < 1e9:
        return n // 100000 * 100000


# t=int(input())
# for _ in range(t):
#     print(solve())

print(solve())

# solve()



N, T, M = map(int, input().split())
# たかだか10人しかいません
hate = set()

for _ in range(M):
    a, b = map(int, input().split())
    hate.add((a, b))
    hate.add((b, a))


def f(now):
    if now == N:
        # nowをNから波及させていくが、そのとき、ちゃんとteamsがTになっていれば1を返すようにする。
        return 1 if len(teams) == T else 0

    ans = 0

    for i in range(len(teams)):
        if len(teams[i]) > 0:
            for t in teams[i]:
                if (now, t) in hate:
                    # 相性悪い人がいる場合
                    break
            else:
                # いない場合
                teams[i].add(now)
                ans += f(now + 1)
                teams[i].remove(now)

    if len(teams) < T:
        teams.append(set([now]))
        ans += f(now + 1)
        teams.pop()

    return ans


teams = []
print(f(0))



S = input()
t = set([])
a = [[]]
for i in S:
    if i.isalpha() == True:
        if i in t:
            print("No")
            exit()
        else:
            t.add(i)
            a[-1].append(i)
    elif i == ")":
        #  print(a)
        for j in a[-1]:
            print(t)
            t.remove(j)
        a.pop(-1)
    elif i == "(":
        a.append([])


#  print(t)
#  print(a)

print("Yes")



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='5\n3\n101\n6\n101101\n5\n11111\n6\n000000\n30\n111011100110101100101000000111\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1\n2\n-1\n0\n8\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



"""Patcher interface for eval harness.

A patcher receives a prompt (plus a context directory path) and returns a single
unified diff that can be applied with `git apply`.
"""

from __future__ import annotations

from dataclasses import dataclass
from pathlib import Path


@dataclass(frozen=True)
class PatchResult:
    diff: str | None
    meta: dict[str, object] | None = None


class Patcher:
    name: str

    def propose_patch(self, *, prompt: str, context_dir: Path, cwd: Path) -> PatchResult:
        raise NotImplementedError



n = int(input())

one = ["H", "D", "C", "S"]
two = ["A", "2", "3", "4", "5", "6", "7", "8", "9", "T", "J", "Q", "K"]

spawned = []

for i in range(n):
    s = input()

    if not s[0] in one or not s[1] in two or not s in spawned:
        print("No")
        exit(0)

    else:
        spawned.append(s)

print("Yes")



from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools


class Solution:
    def pivotArray(self, nums: List[int], pivot: int) -> List[int]:
        lst, val, tmp = [], [], []
        for i in nums:
            if i < pivot:
                val.append(i)
            elif i == pivot:
                lst.append(i)
            else:
                tmp.append(i)
        return lst + val + tmp



import heapq
import sys
from collections import defaultdict, deque
from math import inf

sys.setrecursionlimit(10**6)
MOD = 10**9 + 7

stdin = sys.stdin

ni = lambda: int(ns())
na = lambda: list(map(int, stdin.readline().split()))
ns = lambda: stdin.readline().rstrip()  # ignore trailing spaces

# count the ones in every position
# work out the gain by flipping bit in each position
# calculate the gain per number

n = ni()
A = na()

initial = sum(A)
bits = [0] * 32
for i in range(32):
    for a in A:
        bits[i] += a >> i & 1

value = [0] * n
best = -inf
best_idx = -1
for i in range(n):
    a = A[i]
    for b in range(32):
        if a >> b & 1:
            value[i] += 2**b * (n - bits[b] - bits[b])
    if value[i] > best:
        best = value[i]
        best_idx = i
print(bits)
print(value)
ans = sum(a ^ A[best_idx] for a in A)
print(max(ans, initial))



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='5\n3 1 4 1 5\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '4 5 13 14 26 \n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='6\n1000000000 1000000000 1000000000 1000000000 1000000000 1000000000\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1000000001 2000000001 3000000001 4000000001 5000000001 6000000001 \n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='15\n748 169 586 329 972 529 432 519 408 587 138 249 656 114 632\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '749 918 1921 2250 4861 5390 5822 6428 6836 7796 7934 8294 10109 10223 11373 \n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='1\n1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '2 \n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='1\n1000000000\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1000000001 \n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



from collections import deque

N = int(input())
A = [int(x) for x in input().split()]

A.sort()

deq = deque()
se = set()

non_need = deque()
for a in A:
    if a not in se:
        se.add(a)
        deq.append(a)
    else:
        non_need.append(a)

deq = deq + non_need

for i in range(N):
    ni = i + 1
    if deq and deq[0] == ni:
        deq.popleft()
    elif len(deq) >= 2:
        deq.pop()
        deq.pop()
    else:
        print(i)
        break



from buggy import get_first


def test_cleanup_after_early_break() -> None:
    items, cleaned = get_first(10, 3)
    assert items == [0, 10, 20]
    assert cleaned, "generator cleanup did not run after early break"



import sys

input = sys.stdin.readline


def isPrime(x):
    p = 2
    while p * p <= x:
        if x % p == 0:
            return False
        p += 1
    return True


n = int(input())
li = [list(map(int, input().split())) for _ in range(n)]

from collections import deque
from math import inf


class Dinic:
    """
    Usage:
       mf = Dinic(n)
    -> mf.add_link(from, to, capacity)
    -> mf.max_flow(source, target)
    """

    def __init__(self, n):
        self.n = n
        self.links = [[] for _ in range(n)]

    def add_edge(self, from_, to, capacity):
        self.links[from_].append([capacity, to, len(self.links[to])])
        self.links[to].append([0, from_, len(self.links[from_]) - 1])

    def bfs(self, s):
        depth = [-1] * self.n
        depth[s] = 0
        q = deque([s])
        while q:
            v = q.popleft()
            for cap, to, rev in self.links[v]:
                if cap > 0 and depth[to] < 0:
                    depth[to] = depth[v] + 1
                    q.append(to)
        return depth

    def dfs(self, s, t, depth, progress, link_counts):
        links = self.links
        stack = [s]

        while stack:
            v = stack[-1]
            if v == t:
                break
            for i in range(progress[v], link_counts[v]):
                progress[v] = i
                cap, to, rev = links[v][i]
                if cap == 0 or depth[v] >= depth[to] or progress[to] >= link_counts[to]:
                    continue
                stack.append(to)
                break
            else:
                progress[v] += 1
                stack.pop()
        else:
            return 0

        f = 1 << 60
        fwd_links = []
        bwd_links = []
        for v in stack[:-1]:
            cap, to, rev = link = links[v][progress[v]]
            f = min(f, cap)
            fwd_links.append(link)
            bwd_links.append(links[to][rev])

        for link in fwd_links:
            link[0] -= f

        for link in bwd_links:
            link[0] += f

        return f

    def flow(self, s, t):
        link_counts = list(map(len, self.links))
        flow = 0
        while True:
            depth = self.bfs(s)
            if depth[t] < 0:
                break
            progress = [0] * self.n
            current_flow = self.dfs(s, t, depth, progress, link_counts)
            while current_flow > 0:
                flow += current_flow
                current_flow = self.dfs(s, t, depth, progress, link_counts)
        return flow


mf = Dinic(2 * n + 2)
start = 0
end = 2 * n + 1

for i in range(1, n + 1):
    mf.add_edge(start, i, li[i - 1][1])
    mf.add_edge(i + n, end, li[i - 1][1])

for i in range(n):
    for j in range(n):
        if isPrime(li[i][0] + li[j][1]):
            mf.add_edge(i + 1, j + n + 1, inf)

print(mf.flow(start, end) // 2)



N, K = map(int, input().split())
A = list(map(int, input().split()))
digit = 0
left = 1
right = N * (N + 1) // 2
while digit < N:
    small = [i for i in A[digit:] if i < A[digit]]
    large = [i for i in A[digit:] if i > A[digit]]
    x = False
    if K - left < len(small):
        small.sort()
        x = small[K - left]
    elif right - K < len(large):
        large.sort()
        large.reverse()
        x = large[right - K]
    if not x:
        left += len(small)
        right -= len(large)
        digit += 1
    else:
        j = 0
        while A[j] != x:
            j += 1
        tem = A[:digit] + list(reversed(A[digit : j + 1])) + A[j + 1 :]
        print(tem)
        exit()
print(*A)



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='7 3\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '3\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='123456789123456789 987654321\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '124999999\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='999999999999999998 2\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '499999999999999999\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='406777939015149177 2\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '203388969507574589\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='103838087894477201 4\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '25959521973619301\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



from collections import deque

N = int(input())
A = list(map(int, input().split()))

Q = deque()
ans = 0

for a in A:
    ans += 1
    if len(Q) == 0:
        Q.append([a, 1])
    if Q[-1][0] != a:
        Q.append([a, 1])
    else:
        Q[-1][1] += 1
        if Q[-1][1] == a:
            Q.pop()
            ans -= a
    print(ans)



from buggy import Solution


def test_case_0():
    sol = Solution()
    result = sol.minCost([1,2,1,2,1,3,3], 2)
    assert result == 8


def test_case_1():
    sol = Solution()
    result = sol.minCost([1,2,1,2,1], 2)
    assert result == 6


def test_case_2():
    sol = Solution()
    result = sol.minCost([1,2,1,2,1], 5)
    assert result == 10



from itertools import permutations as perm
from itertools import combinations, product, combinations_with_replacement, groupby, accumulate
from fractions import Fraction
from collections import *
from sys import stdin
from bisect import *
from heapq import *

# import numpy as np
# from math import *

g = lambda: stdin.readline().strip()
# [gl[0], dl[1], ...]
gl = lambda: g().split()
# gl -> int
gil = lambda: [int(var) for var in gl()]
# [n] = gil("A") -> n = A
# [n,m] = gil("A B") -> n = A, M = B
# n=gil("A B C D ...") -> n = [A, B, C, D, ...]

gfl = lambda: [float(var) for var in gl()]

gcl = lambda: list(g())

gbs = lambda: [int(var) for var in g()]
# [n]= gbs("A") -> n = A

arr = lambda l: " ".join(str(n) for n in l)
# arr([1,2,3,...]) -> "1 2 3 ..." 配列で答えをprintする時に使う

mod = int(1e9) + 7
inf = 2**30

[T] = gil()


def query():
    [N, K] = gil()

    Tree = [[] for i in range(N + 1)]
    P = gil()
    A = gil()

    for i, p in enumerate(P, 1):
        p -= 1
        Tree[p].append(i)
        Tree[i].append(p)

    P = [-1] + P

    for i in range(N):
        num = 0
        s = set()
        q = [i]
        while q:
            now = q.pop()
            if A[now] == -1:
                num += 1
            else:
                s.add(A[now])

            for nex in Tree[now]:
                if nex == P[now] - 1:
                    continue
                q.append(nex)

        mex = -1
        need = [0] * (K + 1)
        for j in range(K + 1):
            if j in s:
                need[j] = 1

        if need[K] or num > 1:
            continue  # "Bob"かもしれない

        count = 0

        for j in range(K):
            if need[j] == 0:
                count += 1

        if count == 0:
            return "Alice"
        if count == 1 and num == 1:
            return "Alice"

        return "Bob"


def main():
    for _ in range(T):
        print(query())


if __name__ == "__main__":
    main()



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='.......*\n........\n........\n........\n........\n........\n........\n........\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'h8\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='........\n*.......\n........\n........\n........\n........\n........\n........\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'a7\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='........\n........\n..*.....\n........\n........\n........\n........\n........\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'c6\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='........\n........\n........\n...*....\n........\n........\n........\n........\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'd5\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='........\n........\n........\n........\n......*.\n........\n........\n........\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'g4\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='3 3\n5 4 3\n4 3 2\n3 2 1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '48\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='4 5\n3 1 4 1 5\n9 2 6 5 3\n5 8 9 7 9\n3 2 3 8 4\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '231\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='6 6\n1 300 300 300 300 300\n300 1 300 300 300 300\n300 300 1 300 300 300\n300 300 300 1 300 300\n300 300 300 300 1 300\n300 300 300 300 300 1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '810000\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='1 1\n1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='1 2\n1 1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '2\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



N, L, R = map(int, input().split())
n = format(N, "b")
ans = 0
l = len(n)
x = 2**l
for i in range(len(n)):
    x = x // 2
    if n[i] == "1":
        ans += min(R, 2 * x - 1) - max(L, x) + 1
print(ans)



n = int(input())
S = input()


def f(T):
    U = [c for c in reversed(T)]
    for i in range(len(U)):
        U[i] = "d" if U[i] == "p" else "p"
    return "".join(U)


l = 0
while l < n and S[l] != "d":
    l += 1

ans = S
for r in range(l + 1, n + 1):
    ans = min(ans, S[:l] + f(S[l:r]) + S[r:])
print(ans)



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='8\n"a,b"c,d\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '"a,b"c.d\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='5\n,,,,,\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '.....\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='20\na,"t,"c,"o,"d,"e,"r,\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'a."t,"c."o,"d."e,"r.\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2\n""\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '""\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='3\n","\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '","\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



n = int(input())
rowLeft, colUp = input(), input()
grid = [["." for _ in range(n)] for _ in range(n)]
alphabet = ("A", "B", "C", ".")
rows = [{"A": False, "B": False, "C": False} for _ in range(n)]
cols = [{"A": False, "B": False, "C": False} for _ in range(n)]
rLeftPos = [n] * n
cUpPos = [n] * n


def valid(r: int, c: int, ch: chr) -> bool:
    res = True

    if ch != ".":
        res = rows[r][ch] == False and cols[c][ch] == False

        if c < rLeftPos[r]:
            res = res & (rowLeft[r] == ch)
        if r < cUpPos[c]:
            res = res & (colUp[c] == ch)

    if ch == ".":
        res = n - r - 1 >= 3 - sum(cols[c].values()) and n - c - 1 >= 3 - sum(rows[r].values())
    return res


def setChar(r: int, c: int, ch: chr):
    grid[r][c] = ch

    if ch != ".":
        rows[r][ch] = True
        cols[c][ch] = True

        if r < cUpPos[c]:
            cUpPos[c] = r
        if c < rLeftPos[r]:
            rLeftPos[r] = c


def removeChar(r: int, c: int) -> bool:
    ch = grid[r][c]

    if ch != ".":
        rows[r][ch] = False
        cols[c][ch] = False

        if r == cUpPos[c]:
            cUpPos[c] = n
        if c == rLeftPos[r]:
            rLeftPos[r] = n

    grid[r][c] = "."


def fillPuzzle(r: int, c: int) -> bool:
    # print(sum(cols[r].values()))

    if r >= n:
        return True
    if c >= n:
        return fillPuzzle(r + 1, 0)

    for ch in alphabet:
        if valid(r, c, ch):
            setChar(r, c, ch)
            if fillPuzzle(r, c + 1):
                return True
            removeChar(r, c)
    return False


if fillPuzzle(0, 0):
    print("Yes")
    for line in grid:
        print(line)
else:
    print("No")
# print(sum(rows[0].values()))



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='3 5\n1 3 2\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '2 3 1\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='5 15\n1 2 3 4 5\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '5 4 3 2 1\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='10 37\n9 2 1 3 8 7 10 4 5 6\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '9 2 1 6 5 4 10 7 8 3\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='36 1\n8 22 27 13 20 23 31 15 10 5 3 14 11 1 2 32 35 4 25 17 33 16 19 9 12 7 34 18 24 28 29 21 30 36 26 6\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1 11 14 3 5 10 15 31 23 20 13 27 22 8 2 32 35 4 25 17 33 16 19 9 12 7 34 18 24 28 29 21 30 36 26 6\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='54 1485\n49 16 50 12 21 35 44 40 25 17 3 15 13 22 7 34 54 8 52 20 32 37 29 1 53 24 39 5 10 51 33 6 47 2 23 43 36 11 31 4 27 30 42 45 14 38 18 41 48 28 46 9 19 26\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '54 34 7 22 13 15 3 17 25 40 44 35 21 12 50 16 49 8 52 20 32 37 29 1 53 24 39 5 10 51 33 6 47 2 23 43 36 11 31 4 27 30 42 45 14 38 18 41 48 28 46 9 19 26\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



from buggy import merge_sort


def test_sort_basic() -> None:
    assert merge_sort([3, 1, 2]) == [1, 2, 3]


def test_sort_already_sorted() -> None:
    assert merge_sort([1, 2, 3, 4]) == [1, 2, 3, 4]


def test_sort_reverse() -> None:
    assert merge_sort([5, 4, 3, 2, 1]) == [1, 2, 3, 4, 5]


def test_sort_duplicates() -> None:
    assert merge_sort([3, 1, 3, 2, 1]) == [1, 1, 2, 3, 3]


def test_sort_single() -> None:
    assert merge_sort([42]) == [42]


def test_sort_empty() -> None:
    assert merge_sort([]) == []



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='4\n90 180 45 195\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '120\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='1\n1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '359\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='10\n215 137 320 339 341 41 44 18 241 149\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '170\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='1\n149\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '211\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='15\n31 325 182 184 156 205 223 298 100 186 329 82 279 153 125\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '74\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='4 2\n2 1\n2 3\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '2 4\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='7 9\n6 5\n1 2\n3 4\n5 3\n6 2\n1 5\n3 2\n6 4\n1 4\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1 3 6 7\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='6 1\n3 1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1 2 3 4 5 6\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='7 6\n4 3\n4 2\n4 7\n1 2\n3 5\n6 2\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1 3 4 5 6 7\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='6 7\n6 1\n5 2\n4 1\n4 2\n6 2\n6 5\n3 2\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '3 4 5 6\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools


class Solution:
    def longestPrefix(self, s: str) -> str:
        n = len(s)
        lps = [0] * n
        j = 0
        for i in range(1, n):
            if not self.compareChar(s, i, j):
                j = lps[j - 1]

            if s[i] == s[j]:
                lps[i] = j + 1
                j += 1

        return s[: lps[-1]]



from collections import deque

N = int(input())
S = input()


def solve(N, S):
    rs = []
    As, Cs = 0, 0
    st = False
    for s in S:
        if s == "C":
            Cs += 1
        else:
            if st:
                st = False
                rs[-1] = min(rs[-1], Cs)
            Cs = 0
        if s == "R":
            st = True
            rs.append(As)
        if s == "A":
            As += 1
        else:
            As = 0
    if st:
        rs[-1] = min(rs[-1], Cs)
    print(rs)
    sil, gold = 0, deque()
    for r in rs:
        if r == 0:
            continue
        elif r == 1:
            sil += 1
        else:
            gold.append(r)
    time = 0
    while True:
        time += 1
        if time % 2 == 1:
            if len(gold) != 0:
                p = gold.popleft()
                p -= 1
                if p == 1:
                    sil += 1
                else:
                    gold.append(p)
            elif sil > 0:
                sil -= 1
            else:
                print(time - 1)
                return
        else:
            if sil > 0:
                sil -= 1
            elif len(gold) != 0:
                p = gold.popleft()
            else:
                print(time - 1)
                return


"""
import itertools
import random
s='AAARRRCCC'
lis=list(itertools.permutations(s))
cs=random.sample(lis,5)
for c in cs:
    print(c)
    solve(9,c)
"""

solve(N, S)



s = list(input())
t = list(input())
ans = []
idx = 0
for i in range(len(s)):
    for j in range(idx, len(t)):
        print(i, j)
        if s[i] == t[j]:
            print("A")
            ans.append(j + 1)
            idx = j + 1
            break
print(*ans)



n = int(input())
a = list(map(int, input().split()))

b = []
for i in range(n - 1):
    if a[i] <= a[i + 1]:
        b += list(range(a[i], a[i + 1]))
    if a[i] >= a[i + 1]:
        b += list(range(a[i], a[i + 1], -1))

b.append(a[-1])

print(b)



# B - Balls of Three Colors

MAX = 10**8


def solve(r, g, b):
    def solve1(other1, other2):
        diff = other1 - other2
        if diff % 3 != 0:
            return MAX
        return other2 + diff

    ans = MAX
    ans = min(ans, solve1(max(g, b), min(g, b)))
    ans = min(ans, solve1(max(r, b), min(r, b)))
    ans = min(ans, solve1(max(g, r), min(g, r)))

    return -1 if ans == MAX else ans


t = int(input())
for _ in range(t):
    r, g, b = [int(e) for e in input().split()]
    print(solve(r, g, b))



from bisect import bisect_left


def check(k):
    x = bisect_left(a, k)
    y = m - bisect_left(b, k)
    return x >= y


n, m = map(int, input().split())
a = list(map(int, input().split()))
b = list(map(int, input().split()))
a.sort()
b.sort()
ng = -1
ok = 10**10

while abs(ok - ng) > 1:
    mid = ok + ng >> 1
    if check(mid):
        ok = mid
    else:
        ng = mid

print(ok)



import sys

input = sys.stdin.readline
ii = lambda: int(input())
mi = lambda: map(int, input().split())


N, M, K = mi()
A = list(mi())

# N, M, K = 10,20,7
# A = [6, 5, 0, 2, 0, 0, 0, 15, 0, 0]

# N,M,K = [3, 5, 2]
# A = [2, 0, 4]

###############
MAX = N + 1
MOD = 998244353
fac = [0 for i in range(0, MAX)]
finv = [0 for i in range(0, MAX)]
inv = [0 for i in range(0, MAX)]

fac[0] = fac[1] = 1
inv[1] = 1
finv[0] = finv[1] = 1
for i in range(2, MAX):
    fac[i] = fac[i - 1] * i % MOD
    inv[i] = MOD - MOD // i * inv[MOD % i] % MOD
    finv[i] = finv[i - 1] * inv[i] % MOD


def comb(n, r):
    if n < r or n < 0 or r < 0:
        return 0
    return fac[n] * finv[r] % MOD * finv[n - r] % MOD


###############

A = [a for a in A if a > 0]
A.sort()
Z = N - len(A)  # 0 の個数

import bisect

NC = 0  # 場合の数
NA = pow(M, Z, MOD)  # 全ての場合の数
NAI = pow(NA, MOD - 2, MOD)  # その逆数
for i in range(1, M + 1):
    # i以上となる要素数が N-K+1 以上となる確率の和を求める
    C = len(A) - bisect.bisect_left(A, i)  # i以上の非零要素の個数
    if C >= N - K + 1:
        NC = (NC + NA) % MOD
    elif C + Z < N - K + 1:
        continue
    else:
        # Z個の零要素中N-K+1-C個以上をi以上に置換える
        for m in range(N - K + 1 - C, Z + 1):
            #            print(f'i={i}, comb({Z},{m})*pow({M-i+1},{m})*pow({M},{Z-m})')
            NC = (NC + comb(Z, m) * pow(M - i + 1, m, MOD) * pow(M, Z - m, MOD)) % MOD

print((NC * NAI) % MOD)



from collections import defaultdict

count = defaultdict(int)

A = list(map(int, input().split()))

for i in range(len(A)):
    count[A[i]] += 1

a = count.values()
a = list(a)

if 2 < len(count.values()):
    print("No")
elif a[0] == 3 or a[1] == 3:
    print("YES")
else:
    print("No")



n = int(input())
pp = []
for i in range(n):
    x, y, p = map(int, input().split())
    pp.append((x, y, p))

from collections import deque


def bfs(node, s):
    used = [False] * n
    d = deque()
    d.append(node)
    used[node] = True
    while d:
        tmp = d.popleft()
        p = s * pp[tmp][2]
        for i in range(n):
            if i == tmp:
                continue
            dist = abs(pp[tmp][0] - pp[i][0]) + abs(pp[tmp][1] - pp[i][1])
            if not (used[i]) and p >= dist:
                used[i] = True
                d.append(i)

    return all(used)


l = 1
r = 4 * 10**9
while r - l > 1:
    frag = True
    mid = (l + r) // 2
    for i in range(n):
        if bfs(i, mid):
            r = mid
            frag = False
            break
    if frag:
        l = mid
print(r)



n = int(input())
s = [list(input()) for _ in range(n)]
ans = 100
for i in range(10):
    num = str(i)

    slot = [False for _ in range(n)]
    for j in range(10 * (n + 5)):
        for k in range(n):
            if slot[k] == False and s[k][(j) % 10] == num:
                slot[k] = True

                break
        if all(slot):
            ans = min(ans, j)

            break
print(ans)



# int型で受け取るとき
N = int(input())

# list型で取得
l = list(map(int, input().split()))

height = l[0]

for i in range(N):
    if height < l[i]:
        print(i)
        import sys

        sys.exit()

print(-1)



import asyncio


async def producer(queue: asyncio.Queue[int]) -> None:
    await asyncio.sleep(0.1)
    for i in range(3):
        await queue.put(i * 10)


async def consumer(queue: asyncio.Queue[int]) -> list[int]:
    results: list[int] = []
    for _ in range(3):
        item = await asyncio.wait_for(queue.get(), timeout=0.01)
        results.append(item)
    return results


async def pipeline() -> list[int]:
    queue: asyncio.Queue[int] = asyncio.Queue()
    prod_task = asyncio.create_task(producer(queue))
    result = await consumer(queue)
    await prod_task
    return result


def run_pipeline() -> list[int]:
    return asyncio.run(pipeline())



def isok(x):
    x = str(x)
    for i in range(len(x) // 2):
        if x[i] != x[-i - 1]:
            return False
    return True


n = int(input())
ans = 0
for i in range(n):
    if i**3 <= n and isok(i**3):
        ans = i**3
    elif i**3 > n:
        break
print(ans)



# coding: utf-8
# Your code here!
n, m = map(int, input().split())
s = input()
t = input()
dp = [[[False] for _ in range(m + 1)] for _ in range(n + 1)]
dp[0][0] = True
for i in range(n):
    if i + m <= n:
        for j in range(m + 1):
            if dp[i][j]:
                dp[i][0] = True
    if dp[i][m]:
        for j in range(m + 1):
            dp[i][j] = True
    for j in range(m):
        if dp[i][j] and s[i] == t[j]:
            dp[i + 1][j + 1] = True
print("Yes" if dp[n][m] else "No")



"""mutmut-based mutation testing case generator for llmdebug framework.

Runs mutmut on a target Python module, extracts interesting mutants
(weakly-killed), and converts them into standard case directories.

contamination_risk = "none" — freshly generated from the user's own codebase.
"""

from __future__ import annotations

import re
import shutil
import subprocess
import sys
from pathlib import Path
from typing import Any

from evals.category_mapping import infer_snapshot_dependency, map_mutmut_operator
from evals.importers.base import (
    generate_oracle_patch,
    validate_generated_case,
    write_case_files,
)

# ---------------------------------------------------------------------------
# Filter criteria
# ---------------------------------------------------------------------------

MAX_FIX_LINES = 15


# ---------------------------------------------------------------------------
# mutmut interaction
# ---------------------------------------------------------------------------


def _run_mutmut(target: str) -> tuple[bool, str]:
    """Run mutmut on the target module. Returns (success, message)."""
    try:
        proc = subprocess.run(
            [sys.executable, "-m", "mutmut", "run", "--paths-to-mutate", target],
            capture_output=True,
            text=True,
            timeout=600,
        )
        if proc.returncode != 0:
            return False, f"mutmut exited with code {proc.returncode}: {proc.stderr[:200]}"
        return True, ""
    except subprocess.TimeoutExpired:
        return False, "mutmut timed out after 600s"
    except FileNotFoundError:
        return False, "mutmut not found. Install with: pip install mutmut"


def _get_mutmut_results() -> tuple[list[dict[str, Any]], str]:
    """Query mutmut results. Returns (mutants, error_message)."""
    try:
        proc = subprocess.run(
            [sys.executable, "-m", "mutmut", "results"],
            capture_output=True,
            text=True,
            timeout=30,
        )
        if proc.returncode != 0:
            return [], f"mutmut results exited with code {proc.returncode}: {proc.stderr[:200]}"
        return _parse_mutmut_results(proc.stdout), ""
    except subprocess.TimeoutExpired:
        return [], "mutmut results timed out after 30s"
    except FileNotFoundError:
        return [], "mutmut not found. Install with: pip install mutmut"


def _parse_mutmut_results(output: str) -> list[dict[str, Any]]:
    """Parse mutmut results output into structured data."""
    mutants: list[dict[str, Any]] = []
    # mutmut results format varies; parse for survived/killed/suspicious mutants.
    for line in output.splitlines():
        line = line.strip()
        if not line:
            continue
        # Look for mutant IDs and status.
        match = re.match(r"(\d+)\s+(.+)", line)
        if match:
            mutants.append(
                {
                    "id": match.group(1),
                    "status": match.group(2).strip(),
                }
            )
    return mutants


def _get_mutant_diff(mutant_id: str) -> str | None:
    """Get the diff for a specific mutant."""
    try:
        proc = subprocess.run(
            [sys.executable, "-m", "mutmut", "show", mutant_id],
            capture_output=True,
            text=True,
            timeout=15,
        )
        if proc.returncode == 0 and proc.stdout.strip():
            return proc.stdout
        return None
    except (subprocess.TimeoutExpired, FileNotFoundError):
        return None


def _apply_diff_to_source(original: str, diff: str) -> str | None:
    """Apply a unified diff to original source to produce mutated code.

    Returns mutated source, or None if the diff can't be applied.
    """
    import tempfile

    with tempfile.NamedTemporaryFile(mode="w", suffix=".py", delete=False) as src_f:
        src_f.write(original)
        src_path = src_f.name
    with tempfile.NamedTemporaryFile(mode="w", suffix=".diff", delete=False) as diff_f:
        diff_f.write(diff)
        diff_path = diff_f.name

    try:
        proc = subprocess.run(
            ["patch", "-s", "--no-backup-if-mismatch", src_path, diff_path],
            capture_output=True,
            text=True,
            timeout=5,
        )
        if proc.returncode == 0:
            return Path(src_path).read_text(encoding="utf-8")
        return None
    except (subprocess.TimeoutExpired, FileNotFoundError):
        return None
    finally:
        Path(src_path).unlink(missing_ok=True)
        Path(diff_path).unlink(missing_ok=True)


def _infer_operator_type(diff: str) -> str:
    """Infer mutmut operator type from diff content."""
    if not diff:
        return "keyword"

    # Strip diff markers (+/-/@@) to avoid false positives on diff syntax.
    content_lines = [
        line[1:]
        for line in diff.splitlines()
        if line.startswith("+") or line.startswith("-")
        if not line.startswith("+++") and not line.startswith("---")
    ]
    content = "\n".join(content_lines)
    content_lower = content.lower()

    # Check for common mutation patterns.
    if re.search(r"\w\s*[+\-*/%]\s*\w", content):
        return "arithmetic"
    if any(op in content for op in ["==", "!=", "<=", ">="]):
        return "comparison"
    if re.search(r"(?<!=)[<>](?!=)", content):
        return "comparison"
    if any(kw in content_lower for kw in ["true", "false", "not ", " and ", " or "]):
        return "boolean"
    if "return" in content_lower:
        return "changed_return"
    if re.search(r"\w+\(", content) and re.search(r"^-", diff, re.MULTILINE):
        return "removed_call"
    return "keyword"


# ---------------------------------------------------------------------------
# Test generation for mutants
# ---------------------------------------------------------------------------


def _find_test_file(target: str) -> Path | None:
    """Find the test file that exercises the target module."""
    target_path = Path(target)
    if target_path.is_file():
        module_name = target_path.stem
        # Look in common test locations.
        candidates = [
            target_path.parent / f"test_{module_name}.py",
            target_path.parent.parent / "tests" / f"test_{module_name}.py",
            Path("tests") / f"test_{module_name}.py",
        ]
        for c in candidates:
            if c.exists():
                return c
    return None


# ---------------------------------------------------------------------------
# Main import function
# ---------------------------------------------------------------------------


def import_mutmut(
    output_dir: Path,
    *,
    target: str,
    max_cases: int = 30,
    validate: bool = True,
    dry_run: bool = False,
) -> list[dict[str, Any]]:
    """Generate cases from mutmut mutations on a target module.

    Pipeline:
    1. Run mutmut on target
    2. Query results for interesting mutants
    3. For each mutant: extract diff, create buggy.py, oracle.patch
    4. Validate and write case files

    Args:
        output_dir: Directory to write cases to.
        target: Python module/package to mutate.
        max_cases: Maximum number of cases to generate.
        validate: Whether to schema-validate each case.
        dry_run: If True, preview without writing files.

    Returns list of generated case metadata dicts.
    """
    if dry_run:
        print(f"[dry-run] Would run mutmut on {target} and generate up to {max_cases} cases.")
        return [
            {
                "case_id": f"mut_{Path(target).stem}_preview",
                "metadata": {
                    "bug_source": "mutmut",
                    "contamination_risk": "none",
                    "target": target,
                },
                "fix_lines": 0,
            }
        ]

    # Step 1: Run mutmut.
    print(f"Running mutmut on {target}...")
    ok, err_msg = _run_mutmut(target)
    if not ok:
        print(f"mutmut run failed: {err_msg}")
        return []

    # Step 2: Get results.
    mutants, err_msg = _get_mutmut_results()
    if not mutants:
        print(f"No mutants found.{f' ({err_msg})' if err_msg else ''}")
        return []

    # Step 3: Process killed mutants only (survived mutants pass tests, useless for eval).
    killed = [m for m in mutants if "killed" in m.get("status", "").lower()]
    print(f"Found {len(killed)} killed mutant(s) out of {len(mutants)} total.")

    target_path = Path(target)
    if not target_path.is_file():
        print(f"Target must be a single Python file for case generation: {target}")
        return []

    module_name = target_path.stem
    original_source = target_path.read_text(encoding="utf-8")

    # Find associated test file
    test_file = _find_test_file(target)
    test_code = test_file.read_text(encoding="utf-8") if test_file else ""

    imported: list[dict[str, Any]] = []
    skipped = 0

    for mutant in killed:
        if len(imported) >= max_cases:
            break

        mutant_id = mutant["id"]
        diff = _get_mutant_diff(mutant_id)
        if not diff:
            skipped += 1
            continue

        operator_type = _infer_operator_type(diff)
        category = map_mutmut_operator(operator_type)
        snapshot_dep = infer_snapshot_dependency(category)

        # Apply mutation to get buggy code
        buggy_code = _apply_diff_to_source(original_source, diff)
        if not buggy_code or buggy_code == original_source:
            skipped += 1
            continue

        # Oracle patch: buggy -> fixed (original)
        oracle_patch = generate_oracle_patch(buggy_code, original_source)
        if not oracle_patch.strip():
            skipped += 1
            continue

        if not test_code:
            skipped += 1
            continue

        case_id = f"mut_{module_name}_{mutant_id}"

        metadata = {
            "description": f"mutmut #{mutant_id} on {module_name} ({operator_type})",
            "category": category,
            "difficulty": "easy",
            "snapshot_dependency": snapshot_dep,
            "expected_exception": "AssertionError",
            "tags": ["mutmut", operator_type],
            "python_args": ["-m", "pytest", "-q"],
            "timeout_sec": 30,
            "bug_source": "mutmut",
            "contamination_risk": "none",
            "source_id": f"mutmut_{module_name}_{mutant_id}",
        }

        case_info = {"case_id": case_id, "metadata": metadata, "fix_lines": 0}

        case_dir = output_dir / case_id
        write_case_files(
            case_dir,
            buggy_code=buggy_code,
            test_code=test_code,
            oracle_patch=oracle_patch,
            metadata=metadata,
        )

        if validate:
            ok, msg = validate_generated_case(case_dir, schema_only=True)
            if not ok:
                print(f"  [skip] {case_id}: validation failed: {msg}")
                skipped += 1
                shutil.rmtree(case_dir, ignore_errors=True)
                continue

        imported.append(case_info)

    if skipped:
        print(f"Skipped {skipped} mutant(s).")
    return imported



from buggy import Solution


def test_case_0():
    sol = Solution()
    result = sol.countGoodNumbers(1)
    assert result == 5


def test_case_1():
    sol = Solution()
    result = sol.countGoodNumbers(4)
    assert result == 400


def test_case_2():
    sol = Solution()
    result = sol.countGoodNumbers(50)
    assert result == 564908303



N = int(input())
skill = []
for _ in range(N):
    skill.append(list(map(int, input().split())))

need = [False] * N
need[N - 1] = True
for i in range(N - 1, -1, -1):
    if need[i]:
        for j in skill[i][2:]:
            need[j] = True

ans = 0
for i in range(N):
    if need[i]:
        ans += skill[i][0]
print(ans)



import sys, math, bisect, heapq, copy, decimal, random, fractions
from itertools import permutations, combinations, product, accumulate, groupby
from collections import defaultdict, deque, Counter

input = lambda: sys.stdin.readline().rstrip()
sys.setrecursionlimit(10**8)
"""
n = int(input())
n, m = map(int, input().split())
a = list(map(int, input().split()))
a = [list(map(int, input().split())) for _ in range(n)]
s = input()
s = list(input())
s = [input() for _ in range(n)]
"""


class UnionFind:
    def __init__(self, n):
        self.n = n
        self.parents = [-1] * n

    def find(self, x):
        if self.parents[x] < 0:
            return x
        else:
            self.parents[x] = self.find(self.parents[x])
            return self.parents[x]

    def union(self, x, y):
        x = self.find(x)
        y = self.find(y)

        if x == y:
            return

        if self.parents[x] > self.parents[y]:
            x, y = y, x

        self.parents[x] += self.parents[y]
        self.parents[y] = x

    def size(self, x):
        return -self.parents[self.find(x)]

    def same(self, x, y):
        return self.find(x) == self.find(y)

    def members(self, x):
        root = self.find(x)
        return [i for i in range(self.n) if self.find(i) == root]

    def roots(self):
        return [i for i, x in enumerate(self.parents) if x < 0]

    def group_count(self):
        return len(self.roots())

    def all_group_members(self):
        group_members = defaultdict(list)
        for member in range(self.n):
            group_members[self.find(member)].append(member)
        return group_members

    def __str__(self):
        return "\n".join(f"{r}: {m}" for r, m in self.all_group_members().items())


##########################
n, m, q = map(int, input().split())
E = [list(map(int, input().split())) for _ in range(m)]
Q = [list(map(int, input().split())) for _ in range(q)]

for i in range(m):
    E[i][0] -= 1
    E[i][1] -= 1
for i in range(q):
    Q[i][0] -= 1
    Q[i][1] -= 1
    Q[i].append(i)  # index(3)

uf = UnionFind(n)

E.sort(key=lambda x: x[2])
Q.sort(key=lambda x: x[2])
que = deque(Q)

res = [""] * q

for v, w, c in E:
    while len(que) > 0 and que[0][2] <= c:
        V, W, C, I = que.popleft()

        if uf.same(V, W):
            res[I] = "No"
        else:
            res[I] = "Yes"

    uf.union(v, w)

while len(que) > 0:
    V, W, C, I = que.popleft()

    if uf.same(V, W):
        res[I] = "No"
    else:
        res[I] = "Yes"

print(res)
exit()
for i in res:
    print(i)



from collections import deque

Q = int(input())
q = [list(map(int, input().split())) for _ in range(Q)]

MOD = 998244353


def mod_pow(x, n, mod):
    result = 1
    base = x
    while n > 0:
        if n % 2 == 1:
            result = (result * base) % mod
        base = (base * base) % mod
        n = n // 2
    return result


pos = 0
queue = deque([1])
ans = 1
for d in q:
    if d[0] == 1:
        queue.append(d[1])
        ans = (ans * 10 + d[1]) % MOD
    elif d[0] == 2:
        front = queue.popleft()
        ans = (ans - front * mod_pow(10, len(queue) - 1, MOD)) % MOD
    elif d[0] == 3:
        print(ans)



from buggy import BatchNormalizer


def test_previous_batch_scale_does_not_leak() -> None:
    normalizer = BatchNormalizer()
    assert normalizer.normalize([2, 4]) == [0.5, 1.0]
    assert normalizer.normalize([1, 3]) == [1 / 3, 1.0]



from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools


class Solution:
    def countPoints(self, rings: str) -> int:
        lst = []
        rgb = []
        count = 0
        for i in range(1, len(rings), 2):
            rgb = []
            if rings[i] not in lst:
                lst.append(rings[i])
                for j in range(1, len(rings), 2):
                    if rings[j] == rings[i]:
                        if rings[j - 1] == "R":
                            rgb.append(rings[j - 1])
                        if rings[j - 1] == "G":
                            rgb.append(rings[j - 1])
                        if rings[j - 1] == "B":
                            rgb.append(rings[j - 1])
                if len(set(rgb)) == 2:
                    count += 1
        return count



from itertools import groupby

MOD = 998244353
INF = MOD

H, W = map(int, input().split())
Ss = [input() for _ in range(H)]

if not any("Y" in S for S in Ss):
    print(pow(2, H - 1, MOD) * pow(2, W - 1, MOD) % MOD)
    exit()

lef_trim = 0
while "Y" not in Ss[lef_trim]:
    lef_trim += 1
rig_trim = H
while "Y" not in Ss[rig_trim - 1]:
    rig_trim -= 1

Ss = Ss[lef_trim:rig_trim]
H = rig_trim - lef_trim

csum = [[0] * (W + 1) for _ in range(H + 1)]
for i in range(H):
    for j in range(W):
        csum[i + 1][j + 1] = int(Ss[i][j] == "Y")
for i in range(H + 1):
    for j in range(W):
        csum[i][j + 1] += csum[i][j]
for i in range(H):
    for j in range(W + 1):
        csum[i + 1][j] += csum[i][j]


def get(i_begin, i_end, j_begin, j_end):
    return csum[i_end][j_end] - csum[i_end][j_begin] - csum[i_begin][j_end] + csum[i_begin][j_begin]


# print(Ss)

row_counts = [S.count("Y") for S in Ss]
all_count = sum(row_counts)
first_row_count = 0
cut_counts = set()
for first_row_length in range(H):
    if row_counts[first_row_length] > 0:
        first_row_count += row_counts[first_row_length]
        if first_row_count % 2 == 0 and all_count % first_row_count == 0:
            cut_counts.add(first_row_count)

# print(cut_counts)
answer = 0
for row_count in cut_counts:
    fail = False
    edge_points = [0]
    row_csum = 0
    factor = 1
    length = 0
    for i in range(H):
        row_csum += row_counts[i]
        if length > 0:
            if row_csum:
                factor *= length
                factor %= MOD
                length = 0
            else:
                length += 1
        if row_csum > row_count:
            fail = True
            break
        elif row_csum == row_count:
            edge_points.append(i + 1)
            row_csum = 0
            length = 1
    if row_csum or fail:
        continue

    col_cut_count = row_count // 2 - 1
    lbs_among_row = [-INF] * col_cut_count
    ubs_among_row = [INF] * col_cut_count
    for i in range(len(edge_points) - 1):
        lbs = []
        ubs = []
        i_begin = edge_points[i]
        i_end = edge_points[i + 1]
        count = 0
        for j in range(W):
            count += get(i_begin, i_end, j, j + 1)
            if count and len(lbs) > len(ubs):
                ubs.append(j)
            if count > 2:
                fail = True
                break
            elif count == 2:
                count = 0
                lbs.append(j + 1)
        if fail:
            break
        lbs.pop()
        # print(lbs, ubs, col_cut_count)
        for i in range(col_cut_count):
            lbs_among_row[i] = max(lbs_among_row[i], lbs[i])
            ubs_among_row[i] = min(ubs_among_row[i], ubs[i])
    if fail:
        continue
    col_cut_factor = 1
    for i in range(col_cut_count):
        col_cut_factor *= max(0, ubs_among_row[i] - lbs_among_row[i] + 1)
    answer += factor * col_cut_factor % MOD
    answer %= MOD
    # print(row_count, edge_points, factor, col_cut_factor)
    # print(lbs_among_row, ubs_among_row)

print(answer)



from buggy import Solution


def test_case_0():
    sol = Solution()
    result = sol.minPairSum([3,5,2,3])
    assert result == 7


def test_case_1():
    sol = Solution()
    result = sol.minPairSum([3,5,4,2,4,6])
    assert result == 8



import collections

N = int(input())
AC = [list(map(int, input().split())) for _ in range(N)]
AC = sorted(AC)
AC = sorted(AC, key=lambda x: x[1])
print(AC)
num = AC[0][1]
_min = AC[0][0]
for i in AC[1:]:
    if num != i[1]:
        num = i[1]
        if _min < i[0]:
            _min = i[0]



def check(m, al, a, b):
    a_cnt = 0
    b_cnt = 0
    for num in al:
        diff = abs(num - m)
        if num < diff:
            cnt = diff // a
            if diff % a != 0:
                cnt += 1
            a_cnt += cnt
        else:
            cnt = diff // b
            b_cnt += cnt

    return a_cnt <= b_cnt


def job():
    n, a, b = map(int, input().split())
    al = list(map(int, input().split()))
    left = 0
    right = 10**9 + 100
    while right - left > 1:
        mid = (right + left) // 2
        # もっと答えを大きくできるかも
        if check(mid, al, a, b):
            left = mid
        else:
            # もっとちいさく
            right = mid

    print(left)


job()



N = int(input())

matrix = []
for _ in range(N):
    row = list(map(int, input().strip().split()))
    matrix.append(row)

for i in range(N):
    ans = []
    for j in range(N):
        if matrix[i][j] == 1:
            ans.append(j)
    print(*ans)



import sys

sys.setrecursionlimit(10**8)


H, W = map(int, input().split())
A = [list(map(int, input().split())) for _ in range(H)]
B = [list(map(int, input().split())) for _ in range(H)]


def perm(n):
    rt = []

    def iter(s, acc):
        if not s:
            rt.append(acc[:])
        for i in range(len(s)):
            v = s[i]
            s.remove(v)
            acc.append(v)
            iter(s, acc)
            acc.pop()
            s.insert(i, v)

    iter(list(range(n)), [])
    return rt


def tp(tbl):
    H = len(tbl)
    W = len(tbl[0])
    t = [["" for _ in range(H)] for _ in range(W)]
    for i in range(H):
        for j in range(W):
            t[j][i] = tbl[i][j]
    return t


def f(s):
    n = 0
    for i in range(len(s)):
        for j in range(i):
            if s[j] > s[i]:
                n += 1
    return n


ans = float("inf")
for p in perm(W):
    tbl = []
    for i in range(H):
        t = []
        for j in p:
            t.append(A[i][j])
        tbl.append(t)
    if sorted(tbl) == sorted(B):
        At = tp(tbl)
        Bt = tp(B)
        for q in perm(H):
            tbl = []
            for i in range(W):
                t = []
                for j in q:
                    t.append(At[i][j])
                tbl.append(t)
            if sorted(tbl) == sorted(Bt):
                ans = min(ans, f(p) + f(q))

if ans == float("inf"):
    ans = -1

print(ans)



from collections import deque

t = int(input())
for i in range(t):
    n = int(input())
    s = list(map(str, input()))
    s1, s2 = s, deque()
    tt = False
    ss = True
    for i in range(n - 1):
        s2.appendleft(s1[-1])
        s1.pop()
        for j in range(min(len(s1), len(s2))):
            if ord(s1[j]) < ord(s2[j]):
                print("Yes")
                tt = True
                break
            elif ord(s1[j]) > ord(s2[j]):
                ss = False
                break
        if not tt and ss and len(s1) < len(s2):
            tt = True
            print("Yes")
        if tt:
            break
    if not tt:
        print("No")



from buggy import Solution


def test_case_0():
    sol = Solution()
    result = sol.palindromePairs(["abcd","dcba","lls","s","sssll"])
    assert result == [[0,1],[1,0],[3,2],[2,4]]


def test_case_1():
    sol = Solution()
    result = sol.palindromePairs(["bat","tab","cat"])
    assert result == [[0,1],[1,0]]


def test_case_2():
    sol = Solution()
    result = sol.palindromePairs(["a",""])
    assert result == [[0,1],[1,0]]



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='5 3\n2 1 6 3 1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '11\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='10 1000000000000\n260522 914575 436426 979445 648772 690081 933447 190629 703497 47202\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '826617499998784056\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2 1\n1 1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2 1000000000000\n1 1\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '1000000000000\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2 1000000000000\n999999 999999\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = '999999000000000000\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )



n, m = map(int, input().split())

p = []
c = []
f = []

for i in range(n):
    l = list(map(int, input().split()))
    p.append(l[0])
    c.append(l[1])
    f.append(set(l[2:]))

for i in range(n):
    for j in range(n):
        if p[i] >= p[j]:
            if f[j].issuperset(f[i]):
                print("Yes")
                exit(0)


print("No")



n, t = map(int, input().split())
s = [0 for _ in range(n)]
p = {}
p[0] = n
for i in range(n):
    a, b = map(int, input().split())
    a -= 1
    p[s[a]] -= 1
    if p[s[a]] == 0:
        del p[s[a]]
    s[a] += b
    if s[a] not in p:
        p[s[a]] = 0
    p[s[a]] += 1
    print(len(p))



s = input()
s2 = input()
x = 0
l = []
while len(l) != len(s):
    for i in range(len(s)):
        for j in range(x, len(s2)):
            if s[i] == s2[j]:
                l.append(j + 1)
                x = j
                break
print(*l)



N, A, B, C, D = map(int, input().split())

# XX, XYは(start)X, XX, YXの後にのみ続く
# YX, YYは(start)Y, XY, YYの後にのみ続く

# A, Bの個数はA, Cの個数とほぼ同じ -> Bの個数はCの個数とほぼ同じ
# C, Dの個数はB, Dの個数とほぼ同じ -> Cの個数はBの個数とほぼ同じ

if abs(B - C) == 1:
    print("Yes")
elif B == C and B != 0:
    print("Yes")
elif A == 0 or D == 0:  # B=C=0
    print("Yes")
else:
    print("No")



def count_passing(scores: list[float], threshold: float = 60.0) -> int:
    """Count how many scores meet or exceed the threshold."""
    return sum(score >= threshold for score in scores)


def passing_percentage(scores: list[float], threshold: float = 60.0) -> str:
    """Return percentage of passing scores as a formatted string like '75.0%'."""
    total = len(scores)
    passed = count_passing(scores, threshold)
    ratio = passed // total * 100
    return f"{ratio}%"



from typing import List, Optional, Tuple, Dict, Set
from collections import defaultdict, Counter, deque
import heapq
import math
import bisect
import itertools
import functools


class Solution:
    def findMiddleIndex(self, nums: List[int]) -> int:
        def dnc(l, r, lo, hi):
            if l == r - 1:
                return l if lo == hi else -1

            mid = (l + r) // 2
            right = sum(nums[mid:r])
            left = sum(nums[l:mid])

            left_ind = dnc(l, mid, lo, hi + right)
            return left_ind if left_ind != -1 else dnc(mid, r, lo + left, hi)

        return dnc(0, len(nums), 0, undefined_variable)



"""Tests for DebugSession schema helpers."""

from __future__ import annotations

from typing import Any

from llmdebug._debug_session import (
    build_debug_session,
    coerce_crash_frame_index,
    is_debug_session_payload,
    normalize_snapshot_view,
    split_extra_context,
)


def test_split_extra_context_none() -> None:
    context, trace_payload, eval_payload = split_extra_context(None)
    assert context == {}
    assert trace_payload is None
    assert eval_payload is None


def test_split_extra_context_extracts_trace_and_eval() -> None:
    extra: dict[str, Any] = {
        "hook": "sys.excepthook",
        "trace": {"spans": [1]},
        "eval_outcome": {"status": "failed"},
    }
    context, trace_payload, eval_payload = split_extra_context(extra)
    assert context == {"hook": "sys.excepthook"}
    assert trace_payload == {"spans": [1]}
    assert eval_payload == {"status": "failed"}
    # Ensure source dict is not mutated
    assert "trace" in extra
    assert "eval_outcome" in extra


def test_build_debug_session_minimal() -> None:
    payload = build_debug_session(
        name="unit_test",
        timestamp_utc="2026-02-10T12:00:00Z",
        llmdebug_version="2.1.0",
        snapshot={"exception": {"type": "ValueError"}, "frames": []},
    )
    assert payload["schema_version"] == "2.0"
    assert payload["kind"] == "llmdebug.debug_session"
    assert payload["session"]["name"] == "unit_test"
    assert payload["snapshot"]["exception"]["type"] == "ValueError"
    assert "context" not in payload
    assert "trace" not in payload
    assert "eval" not in payload


def test_is_debug_session_payload() -> None:
    assert not is_debug_session_payload({})
    assert not is_debug_session_payload({"session": {}, "snapshot": {}})
    assert not is_debug_session_payload(
        {"kind": "other.kind", "session": {"name": "x"}, "snapshot": {"frames": []}}
    )
    assert not is_debug_session_payload({"session": {"name": "x"}, "snapshot": {"frames": []}})
    assert is_debug_session_payload(
        {"kind": "llmdebug.debug_session", "session": {"name": "x"}, "snapshot": {"frames": []}}
    )
    # Kind is optional for backward compatibility
    assert is_debug_session_payload(
        {"schema_version": "2.0", "session": {"name": "x"}, "snapshot": {"frames": []}}
    )


def test_normalize_snapshot_view_passthrough_for_legacy() -> None:
    legacy = {"schema_version": "1.0", "name": "legacy", "exception": {"type": "E"}, "frames": []}
    out = normalize_snapshot_view(legacy)
    assert out is legacy


def test_normalize_snapshot_view_envelope_context_overrides_snapshot() -> None:
    payload = {
        "schema_version": "2.0",
        "kind": "llmdebug.debug_session",
        "session": {"name": "case", "timestamp_utc": "2026-02-10T12:00:00Z"},
        "snapshot": {"exception": {"type": "E"}, "frames": [], "hook": "from_snapshot"},
        "context": {"hook": "from_context"},
    }
    out = normalize_snapshot_view(payload)
    assert out["name"] == "case"
    assert out["timestamp_utc"] == "2026-02-10T12:00:00Z"
    assert out["hook"] == "from_context"


def test_normalize_snapshot_view_fallbacks_and_extras() -> None:
    payload = {
        "schema_version": "2.0",
        "kind": "llmdebug.debug_session",
        "name": "top_name",
        "timestamp_utc": "2026-02-10T12:34:00Z",
        "llmdebug_version": "2.1.0",
        "session": {},  # Intentionally partial
        "snapshot": {"exception": {"type": "TypeError"}, "frames": []},
        "trace": {"spans": [1, 2]},
        "eval": {"status": "failed"},
        "custom_key": {"x": 1},
    }
    out = normalize_snapshot_view(payload)
    assert out["name"] == "top_name"
    assert out["timestamp_utc"] == "2026-02-10T12:34:00Z"
    assert out["llmdebug_version"] == "2.1.0"
    assert out["trace"] == {"spans": [1, 2]}
    assert out["eval"] == {"status": "failed"}
    assert out["custom_key"] == {"x": 1}


def test_coerce_crash_frame_index_handles_invalid_values() -> None:
    snapshot = {
        "frames": [
            {"function": "crash"},
            {"function": "caller"},
        ],
        "crash_frame_index": "abc",
    }
    assert coerce_crash_frame_index(snapshot) == 0


def test_coerce_crash_frame_index_falls_back_to_first_dict_frame() -> None:
    snapshot = {
        "frames": [
            "bad-frame",
            {"function": "good-frame"},
            {"function": "other-frame"},
        ],
        "crash_frame_index": 0,
    }
    assert coerce_crash_frame_index(snapshot) == 1


def test_coerce_crash_frame_index_defaults_when_frames_missing() -> None:
    snapshot = {
        "frames": None,
        "crash_frame_index": 3,
    }
    assert coerce_crash_frame_index(snapshot) == 0


def test_coerce_crash_frame_index_defaults_when_no_dict_frame_exists() -> None:
    snapshot = {
        "frames": ["bad-frame", 3, None],
        "crash_frame_index": 1,
    }
    assert coerce_crash_frame_index(snapshot) == 0



N = int(input())
S = [ord(s) - ord("a") for s in input()]
T = [ord(s) - ord("a") for s in input()]
Ns, Nt = len(S), len(T)
A = [[] for i in range(26)]
S = S + S
for i in range(2 * Ns):
    A[S[i]].append(i)

for i in range(Nt):
    if len(A[T[i]]) == 0:
        print(0)
        exit()

C = [[0] * (2 * Ns) for i in range(26)]
Ac = [[0] * (2 * Ns + 1) for i in range(26)]
for i in range(2 * Ns):
    C[S[i]][i] = 1

for c in range(26):
    for i in range(2 * Ns):
        Ac[c][i + 1] = Ac[c][i] + C[c][i]

cnt = []
for i in range(26):
    cnt.append(Ac[i][-1] // 2)


def check(m):
    now = 0
    v = 0
    for t in T:
        q = (m - 1) // cnt[t]
        r = m - q * cnt[t]
        v += q * Ns
        st = Ac[t][now]
        now = A[t][st + r - 1] + 1
        if now >= Ns:
            v += Ns
            now -= Ns
    v += now + 1
    return v <= N * Ns


def BinarySearch(yes=10**18, no=-1):
    while abs(yes - no) != 1:
        mid = (yes + no) // 2
        if check(mid):
            yes = mid
        else:
            no = mid
    return yes


yes = 0
no = 10**18
print(BinarySearch(yes, no))



import subprocess
import sys


def test_condefects_0():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='3\nabc\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'Yes\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_1():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='2\nba\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'Yes\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_2():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='7\natcoder\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'No\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_3():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='37\nqeixfumagitvtophbepfepxbfgsqcugugpugt\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'No\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )


def test_condefects_4():
    proc = subprocess.run(
        [sys.executable, "buggy.py"],
        input='100\nqbfhehfkqfmglrjaienfqiqacfpfjhaddglpaaacsqojiosfscakihlslinkpieboqoennjdhibgcgfdkfjldnnlpdljkcsfojkd\n',
        capture_output=True,
        text=True,
        timeout=10,
    )
    expected = 'No\n'
    actual = proc.stdout.strip()
    assert actual == expected.strip(), (
        f"Expected {expected.strip()!r}, got {actual!r}"
    )
